a='''<?xml version="1.0" encoding="utf-8" standalone="yes"?>
<Hublist Name="Team Elite Hublist" Address="https://www.te-home.net/?do=hublist">
	<Hubs>
		<Columns>
			<Column Name="Name" Type="string" />
			<Column Name="Address" Type="string" />
			<Column Name="Secure" Type="string" />
			<Column Name="Description" Type="string" />
			<Column Name="Country" Type="string" />
			<Column Name="Encoding" Type="string" />
			<Column Name="Users" Type="int" />
			<Column Name="Operators" Type="int" />
			<Column Name="Bots" Type="int" />
			<Column Name="Clones" Type="int" />
			<Column Name="Infected" Type="int" />
			<Column Name="Shared" Type="bytes" />
			<Column Name="Minshare" Type="bytes" />
			<Column Name="Minslots" Type="int" />
			<Column Name="Maxhubs" Type="int" />
			<Column Name="Maxusers" Type="int" />
			<Column Name="Status" Type="string" />
			<Column Name="Reliability" Type="string" />
			<Column Name="Rating" Type="string" />
			<Column Name="Software" Type="string" />
			<Column Name="Website" Type="string" />
			<Column Name="Email" Type="string" />
			<Column Name="ASN" Type="string" />
			<Column Name="Network" Type="string" />
			<Column Name="Failover" Type="string" />
			<Column Name="Logo" Type="string" />
			<Column Name="Icon" Type="string" />
		</Columns>
		<Hub Name="White Nights of St. Petersburg" Address="piter.feardc.net" Secure="nmdcs://piter.feardc.net:411" Description="#1, St. Petersburg, Russia, AllAvtovo.ru, DCShara.ru, LamaLama.tv, S125.ru, Nemesis, Team Elite, Verlihub, NMDCS, TLS 1.3" Country="Russian Federation" Encoding="CP1251" Users="3284" Operators="9" Bots="5" Clones="75" Infected="0" Shared="2228655767614242" Minshare="0" Minslots="1" Maxhubs="0" Maxusers="20000" Status="Online" Reliability="99.95" Rating="2005" Software="Verlihub" Website="https://te-home.net/" Email="webmaster@feardc.net" ASN="OVH SAS" Network="Team Elite" Failover="nemesis.te-home.net" Logo="https://te-home.net/gallery/piter.jpg" Icon="https://te-home.net/favicon.ico" />
		<Hub Name="Angels vs Demons" Address="dc.kcahdep.online" Secure="" Description="Cogitationis poenam nemo patitur." Country="Russian Federation" Encoding="CP1251" Users="2101" Operators="4" Bots="9" Clones="49" Infected="0" Shared="1764896847566482" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="20480" Status="Online" Reliability="99.56" Rating="381" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="https://i.ytimg.com/vi/mYgdErk4q70/maxresdefault.jpg" Icon="https://my-files.su/Get/jz154e/favicon.ico" />
		<Hub Name="FlylinkDC++ hub" Address="dc.fly-server.ru" Secure="" Description="Хаб фанатов FlylinkDC++" Country="Russian Federation" Encoding="CP1251" Users="2084" Operators="4" Bots="0" Clones="13" Infected="1" Shared="1547160779734132" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="10000" Status="Online" Reliability="96.95" Rating="4" Software="PtokaX" Website="http://flylinkdc.com/" Email="pavel.pimenov@gmail.com" ASN="NTX Technologies s.r.o." Network="" Failover="" Logo="https://raw.githubusercontent.com/pavel-pimenov/flylinkdc-r5xx/master/res/FlyLink.png" Icon="http://flylinkdc.com/favicon.ico" />
		<Hub Name="Rutrack DC.Hub" Address="dc.rutrack.net" Secure="" Description="The Russian Hub for all World" Country="Russian Federation" Encoding="CP1251" Users="1761" Operators="1" Bots="0" Clones="20" Infected="10" Shared="1716682958448273" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="20000" Status="Online" Reliability="96.59" Rating="2" Software="PtokaX" Website="" Email="dc@rutrack.net" ASN="Zomro B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="DC•Filimania•COM" Address="dc.filimania.com" Secure="" Description="Russian HUB" Country="Russian Federation" Encoding="CP1251" Users="1725" Operators="2" Bots="0" Clones="19" Infected="0" Shared="1579896012109023" Minshare="0" Minslots="1" Maxhubs="0" Maxusers="16000" Status="Online" Reliability="99.61" Rating="0" Software="PtokaX" Website="http://filimania.com/" Email="filimania@mail.ru" ASN="Hetzner Online GmbH" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[RU] Novosibirsk-Forever" Address="novosibirsk.dc-dev.club" Secure="" Description="Enjoy and stay!" Country="Russian Federation" Encoding="CP1251" Users="1715" Operators="12" Bots="0" Clones="270" Infected="7" Shared="943209769296109" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="10000" Status="Online" Reliability="96.33" Rating="1" Software="PtokaX" Website="" Email="admin@dchublist.org" ASN="UUNET" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Хаб-Знакомств-И-Друзей" Address="lig-cs.ru" Secure="" Description="TNEY LIVE - OBEY" Country="Russian Federation" Encoding="CP1251" Users="1688" Operators="5" Bots="0" Clones="254" Infected="4" Shared="1113106232562711" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="10000" Status="Online" Reliability="83.36" Rating="0" Software="PtokaX" Website="" Email="gribton@mail.ru" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="#EliteDC.Hub" Address="dc.elitedc.ru" Secure="" Description="VPS Server от 55 руб / VPS Server from €1,26 &gt;&gt;&gt;&gt;&gt; https://firstbyte.ru/?from=5031/ &lt;&lt;&lt;&lt;&lt;" Country="Russian Federation" Encoding="CP1251" Users="1595" Operators="9" Bots="0" Clones="124" Infected="7" Shared="1536647884406775" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="10000" Status="Online" Reliability="97.85" Rating="5" Software="PtokaX" Website="http://www.elitedc.ru/" Email="admin@elitedc.ru" ASN="OVH SAS" Network="Elite DC" Failover="" Logo="http://hub.elitedc.ru/images/logo.png" Icon="http://hub.elitedc.ru/favicon.ico" />
		<Hub Name="ArtCool.ORG" Address="artcool.org" Secure="" Description="Saint-Petersburg•Russia" Country="Russian Federation" Encoding="CP1251" Users="1588" Operators="1" Bots="0" Clones="6" Infected="9" Shared="1399566975096662" Minshare="0" Minslots="1" Maxhubs="99" Maxusers="15000" Status="Online" Reliability="97.56" Rating="0" Software="PtokaX" Website="http://artcool.org/" Email="admin@artcool.org" ASN="JSC ER-Telecom Holding" Network="InterZet" Failover="" Logo="" Icon="" />
		<Hub Name="Пикник" Address="piknik-dc.ru" Secure="" Description="Пикник" Country="Russian Federation" Encoding="CP1251" Users="1579" Operators="3" Bots="0" Clones="16" Infected="8" Shared="1248981215679463" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="19999" Status="Online" Reliability="98.82" Rating="0" Software="PtokaX" Website="http://piknik-dc.ru/" Email="admin@piknik-spb.ru" ASN="ArtPlanet LLC" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Adrenalin Hub" Address="aab-new-adrenalin.ru" Secure="" Description="New Adrenalin" Country="Russian Federation" Encoding="CP1251" Users="1576" Operators="7" Bots="0" Clones="19" Infected="8" Shared="1305561229628929" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="5000" Status="Online" Reliability="99.4" Rating="0" Software="PtokaX" Website="" Email="abakum1977@mail.ru" ASN="ArtPlanet LLC" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Stealth Group - Hub™" Address="stealthhub.ru" Secure="" Description="Викторина, приятный колектив и адекватная администрация! Заходи!!! Общайся , Качай!!!" Country="Russian Federation" Encoding="CP1251" Users="1378" Operators="4" Bots="0" Clones="39" Infected="0" Shared="906617338709670" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="10000" Status="Online" Reliability="94.22" Rating="0" Software="PtokaX" Website="http://stealthhub.ru/" Email="admin@stealthhub.ru" ASN="Iskratelecom CJSC" Network="" Failover="" Logo="http://stealthhub.ru/baner.png" Icon="http://stealthhub.ru/favicon.png" />
		<Hub Name="HMn DC Hub" Address="hmn.pp.ru" Secure="" Description="VPS Server от 55 руб &gt;&gt;&gt;&gt;&gt; https://firstbyte.ru/?from=27398 &lt;&lt;&lt;&lt;&lt;" Country="Russian Federation" Encoding="CP1251" Users="1111" Operators="14" Bots="0" Clones="133" Infected="1" Shared="1701206312004877" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="10000" Status="Online" Reliability="99.7" Rating="8" Software="PtokaX" Website="" Email="expert-k@list.ru" ASN="Network Management Ltd" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="FAVORITE Group" Address="favorite-hub.net" Secure="" Description="DC•torrent" Country="Russian Federation" Encoding="CP1251" Users="1050" Operators="7" Bots="0" Clones="59" Infected="10" Shared="1233817757445822" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="32767" Status="Online" Reliability="98.89" Rating="0" Software="PtokaX" Website="http://favorite-hub.net/" Email="rola.ru@list.ru" ASN="Network Management Ltd" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Mich-FOREVER-HUB" Address="mich-forever.ru" Secure="nmdcs://mich-forever.ru:411" Description="dchub://mich-forever.ru Добавьте хаб в избранные! После входа на хаб, введите команду /fav в чат. После этого, нажмите Ctrl+F и поставьте галочку рядом с Mich-FOREVER-HUB" Country="Russian Federation" Encoding="CP1251" Users="1045" Operators="1" Bots="4" Clones="12" Infected="7" Shared="688036088879503" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="8000" Status="Online" Reliability="99.51" Rating="0" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Магнит-хаб" Address="hub.magnet.211.ru" Secure="" Description="Магнит-хаб" Country="Russian Federation" Encoding="CP1251" Users="926" Operators="2" Bots="0" Clones="5" Infected="10" Shared="850933667016612" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="20000" Status="Online" Reliability="98.53" Rating="-1" Software="Verlihub" Website="http://magnet.211.ru/" Email="" ASN="Sibirskie Seti Ltd." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Дальний Восток" Address="vostokhub.ru" Secure="" Description="" Country="Russian Federation" Encoding="CP1251" Users="946" Operators="3" Bots="6" Clones="3" Infected="0" Shared="527827838450757" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="20480" Status="Online" Reliability="94.67" Rating="0" Software="Verlihub" Website="" Email="" ASN="IP Ivanov Dmitry Alekseevich" Network="" Failover="" Logo="https://ds03.infourok.ru/uploads/ex/0fbd/00031cfc-2bcc6a99/2/img12.jpg" Icon="https://www.favicon.by/download.php?favicon=60696612c8edf.ico" />
		<Hub Name="Globalnet" Address="globalnet.ovh" Secure="" Description="" Country="Ukraine" Encoding="CP1251" Users="802" Operators="4" Bots="4" Clones="15" Infected="1" Shared="664023051613368" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="20480" Status="Online" Reliability="98.21" Rating="1" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="https://sun9-51.userapi.com/WJC-OSFHMSoflcjxDDz4GrBeZYZFfXSuOpk0PA/cmcVZBW0LUE.jpg" Icon="https://banner2.cleanpng.com/20180219/sdw/kisspng-global-network-st-paul-training-llp-clip-art-web-symbol-cliparts-5a8a7eeb82bf49.9620279315190258995356.jpg" />
		<Hub Name="#Ninjas Are Back" Address="dc.ninjasareback.com" Secure="nmdcs://dc.ninjasareback.com:411" Description="••• TLS 1.3 SECURED ••• NO LIMIT ••• WELCOME ALL •••" Country="Hungary" Encoding="CP1250" Users="743" Operators="3" Bots="3" Clones="4" Infected="0" Shared="311007305021760" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="2000" Status="Online" Reliability="99.77" Rating="560" Software="Verlihub" Website="https://dc.ninjasareback.com/" Email="ninjasareback@protonmail.com" ASN="OVH SAS" Network="" Failover="vip.feardc.net" Logo="https://www.te-home.net/data_files/misc/ninjas_logo.png" Icon="https://www.te-home.net/data_files/misc/ninjas_icon.png" />
		<Hub Name="Lithuania DC++" Address="dchub.lt" Secure="nmdcs://dchub.lt:411" Description="Lithuania, Vilnius, Online 24/365" Country="Lithuania" Encoding="CP1257" Users="734" Operators="2" Bots="3" Clones="3" Infected="0" Shared="431450840153797" Minshare="0" Minslots="1" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="100" Rating="651" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="https://www.te-home.net/gallery/trakai.jpg" Icon="https://icons.iconarchive.com/icons/custom-icon-design/round-world-flags/16/Lithuania-icon.png" />
		<Hub Name="Club-Fantasy -|- I n t e r n a t i o n a l" Address="club-fantasy-hub.ro" Secure="" Description="Club-Fantasy -|- I n t e r n a t i o n a l Hub of Romania Russia Belarus Italy Spain United Kingdom France Ukraine USA Sweden Netherlands Hungary Norway Finland Poland Germany India Brazil Indonesia Bangladesh Thailand and more" Country="Romania" Encoding="CP1252" Users="702" Operators="2" Bots="4" Clones="57" Infected="12" Shared="717952424779699" Minshare="1073741824" Minslots="0" Maxhubs="0" Maxusers="100000" Status="Online" Reliability="98.94" Rating="9" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="Club Fantasy Network" Failover="" Logo="http://club-fantasy-hub.ro/4.png" Icon="http://club-fantasy-hub.ro/4.png" />
		<Hub Name="BigNet" Address="dc.bignet.ro" Secure="" Description="Romania - Bucuresti - Romania - Download - Muzica - Trance - House - MP3 - Music - Mobile - International - FiberLink - BigShare - Programe - Mac - Linux - Windows - Images - Covers - Pictures - Games - PS3 - PSP - Rar - Iso - Apps - Crack - KeyGen - Film" Country="Romania" Encoding="CP1252" Users="656" Operators="0" Bots="2" Clones="10" Infected="8" Shared="801367306493263" Minshare="1073741824" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="98.4" Rating="2" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="Big Network" Failover="" Logo="" Icon="" />
		<Hub Name="i.n.t.e.r.n.a.t.i.o.n.a.l®" Address="international.dchub.net" Secure="" Description="International DC++" Country="Italy" Encoding="CP1252" Users="642" Operators="3" Bots="3" Clones="11" Infected="0" Shared="651460733220913" Minshare="1073741824" Minslots="0" Maxhubs="1000" Maxusers="14999" Status="Online" Reliability="99.3" Rating="0" Software="Verlihub" Website="" Email="" ASN="ArtPlanet LLC" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="XOT.HUBDC.RU: XDN+Ozerki+TiERA" Address="xot.hubdc.ru" Secure="" Description="Тиера + Озерки + ХДН" Country="Russian Federation" Encoding="CP1251" Users="601" Operators="2" Bots="0" Clones="14" Infected="10" Shared="744631730837890" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="10000" Status="Online" Reliability="99.46" Rating="0" Software="PtokaX" Website="" Email="admin@hubdc.ru" ASN="ArtPlanet LLC" Network="Hub DC" Failover="" Logo="" Icon="" />
		<Hub Name="Монплеzир" Address="oktavy.sytes.net" Secure="" Description="DC++ хаб Петергофа" Country="Russian Federation" Encoding="CP1251" Users="547" Operators="3" Bots="0" Clones="19" Infected="3" Shared="380405330999054" Minshare="536870912" Minslots="0" Maxhubs="0" Maxusers="2000" Status="Online" Reliability="95.61" Rating="0" Software="PtokaX" Website="http://evmeste.ru/" Email="anektos@yandex.ru" ASN="Domain names registrar REG.RU, Ltd" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="• S K O R P I O N • H U B •" Address="skorpion.dchub.pl:58111" Secure="nmdcs://skorpion.dchub.pl:58111" Description="L O D Z - P O L A N D" Country="Poland" Encoding="CP1250" Users="459" Operators="8" Bots="4" Clones="28" Infected="0" Shared="224430621623919" Minshare="26843545600" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="98.6" Rating="334" Software="Verlihub" Website="http://skorpion.dchub.pl/" Email="skorpion54@o2.pl" ASN="Nazwa.pl Sp.z.o.o." Network="" Failover="" Logo="https://img.theculturetrip.com/768x/smart/wp-content/uploads/2018/03/shutterstock_491464879-shaiith.jpg" Icon="http://skorpion.dchub.pl/images.png" />
		<Hub Name="dchub.xyz" Address="dchub.xyz" Secure="" Description="E U R O P E dchub.xyz E U R O P E dchub.xyz E U R O P E" Country="Romania" Encoding="CP1252" Users="410" Operators="0" Bots="2" Clones="1" Infected="9" Shared="356099307829907" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="99.59" Rating="1" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Verlihub.ORG" Address="verlihub.org:4111" Secure="" Description="World DC Hub. Работает с 12.08.2006." Country="Russian Federation" Encoding="CP1251" Users="399" Operators="0" Bots="4" Clones="3" Infected="6" Shared="423714367740969" Minshare="0" Minslots="0" Maxhubs="20000" Maxusers="24000" Status="Online" Reliability="97.12" Rating="1" Software="Verlihub" Website="http://verlihub.org/" Email="" ASN="PVimpelCom" Network="" Failover="" Logo="http://www.verlihub.org/pics/verlihub-org.png" Icon="http://www.verlihub.org/pics/v.png" />
		<Hub Name="ÐØTTØRÊSSA &amp; JØLL¥JØKÊR Hµß" Address="roman-trivia.freeway-fun.net" Secure="" Description="bine ai venit - welcome to all" Country="Italy" Encoding="CP1252" Users="382" Operators="4" Bots="4" Clones="12" Infected="5" Shared="268531327047043" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="3000" Status="Online" Reliability="97.92" Rating="0" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="Freeway Fun Network" Failover="" Logo="" Icon="" />
		<Hub Name="Moscow.Hub" Address="dchub.msk.ru" Secure="" Description="Hub in Moscow" Country="Russian Federation" Encoding="CP1251" Users="404" Operators="9" Bots="0" Clones="10" Infected="4" Shared="547760014802557" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="5000" Status="Online" Reliability="99.36" Rating="0" Software="PtokaX" Website="" Email="karumo@mail.ru" ASN="Network Management Ltd" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="42ØKing§™" Address="420kings.420-net.org:420" Secure="" Description="It&apos;s 4:19 Who&apos;s Got a Min??" Country="United Kingdom" Encoding="CP1252" Users="372" Operators="9" Bots="3" Clones="6" Infected="4" Shared="354093573005547" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="85.56" Rating="1" Software="Verlihub" Website="https://www.420-net.org/" Email="" ASN="Host Europe GmbH" Network="420 Network" Failover="" Logo="" Icon="" />
		<Hub Name="GTK LAV" Address="hubdc.ru" Secure="" Description="Объединенный хаб сети GTK" Country="Russian Federation" Encoding="CP1251" Users="353" Operators="1" Bots="0" Clones="28" Infected="7" Shared="416122258293090" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="10000" Status="Online" Reliability="99.48" Rating="-1" Software="PtokaX" Website="http://hubdc.ru/" Email="admin@hubdc.ru" ASN="Resource-M LLC" Network="Hub DC" Failover="" Logo="" Icon="" />
		<Hub Name="ВИКТОРИНА DC Hub" Address="victorina.pp.ua" Secure="" Description="VPS Server from 1 / 77 руб в мес &gt;&gt;&gt;&gt;&gt; https://firstbyte.ru/?from=27398 &lt;&lt;&lt;&lt;&lt; НОВЫЙ АДРЕС ХАБА: dchub://victorina.pp.ua" Country="Ukraine" Encoding="CP1251" Users="337" Operators="1" Bots="0" Clones="20" Infected="10" Shared="400164241154014" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="98.81" Rating="1" Software="PtokaX" Website="" Email="" ASN="JSC Avantel" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[_Rebel-Zone_] - [ Hub National ] - [ #StaySafe ] - [ Share &amp; Enjoy !] - - - [ dchub://hub.rebelnetwork.ro ]..............................................." Address="hub.rebelnetwork.ro" Secure="" Description="Super Viteza pentru toti utilizatorii din Romania!" Country="Romania" Encoding="CP1252" Users="315" Operators="0" Bots="2" Clones="8" Infected="9" Shared="91262605946218" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="10000" Status="Online" Reliability="96.98" Rating="2" Software="Verlihub" Website="http://rebelnetwork.ro/" Email="" ASN="UAB Rakrejus" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Prapor Hub" Address="dc.prapor.in" Secure="" Description="Russian Moscow Work 24h" Country="Russian Federation" Encoding="CP1251" Users="305" Operators="5" Bots="0" Clones="3" Infected="4" Shared="247801236941266" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="10000" Status="Online" Reliability="99.22" Rating="0" Software="PtokaX" Website="http://prapor.in/" Email="admin@prapor.in" ASN="PJSC Moscow city telephone network" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="• ][ EuRoPe ShArE NeTwOrK ][ PrEtOrIAno AnD ChAos HuB ConNeCT •" Address="dc.europeshare.net" Secure="" Description="bine ai venit - Joaca cu la trivia :D" Country="Italy" Encoding="CP1252" Users="297" Operators="1" Bots="7" Clones="16" Infected="9" Shared="259116429206470" Minshare="0" Minslots="0" Maxhubs="300" Maxusers="6000" Status="Online" Reliability="98.78" Rating="0" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="Europe Share" Failover="" Logo="" Icon="" />
		<Hub Name="• RomanTrivia • Clå®K K€ñT ]-[ûß •" Address="roman-trivia.freeway-fun.net:4111" Secure="" Description="bine ai venit - welcome to all" Country="Romania" Encoding="CP1252" Users="286" Operators="0" Bots="9" Clones="2" Infected="12" Shared="137666685834126" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="95.62" Rating="0" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="Freeway Fun Network" Failover="" Logo="" Icon="" />
		<Hub Name="=BasicGames= DC++" Address="star.basicgames.eu:9444" Secure="" Description="INTERNATIONAL BASICGAMES UpSpeed Download Constanta R3volutionSTAR Romania Bucuresti Shooter Rar Apps mpeg Punk Download avi Covers Games Pictures Comics Rap International Windows HipHop porn Trance TT Chat images Techno Mp3 Music Prison Break Movies Netw" Country="Romania" Encoding="CP1252" Users="275" Operators="14" Bots="3" Clones="14" Infected="10" Shared="314932720700979" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="92.27" Rating="0" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="©-O [DjDeLiA&apos;s HUB-X ] O-©" Address="djdelia.club-fantasy-hub.ro" Secure="" Description="~”*°•. .::: ©-O [DjDeLiA&apos;s HUB-X ] O-© ...:::... BRASOV 2oo3 -2o2o•°*”~" Country="Romania" Encoding="CP1252" Users="253" Operators="3" Bots="2" Clones="3" Infected="5" Shared="156317636737589" Minshare="1073741824" Minslots="0" Maxhubs="50000" Maxusers="10000" Status="Online" Reliability="99.58" Rating="0" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="Club Fantasy Network" Failover="" Logo="" Icon="" />
		<Hub Name="RomanticNET AliianceHub" Address="dc.romanticnet.ro:4112" Secure="" Description="ROMANIA BUCURESTI Rar Apps mpeg Punk Download avi Covers Pictures Comics Rap International Windows HipHop porn Trance Chat images Techno Mp3 Music Prison Break Movies Network TV shows divx Gossip Girl Audio books PS3 Sound clips Warez mpg Games swiss Grey" Country="Romania" Encoding="CP1252" Users="249" Operators="6" Bots="3" Clones="4" Infected="5" Shared="196663618835953" Minshare="1048576" Minslots="0" Maxhubs="100" Maxusers="3024" Status="Online" Reliability="97.91" Rating="0" Software="Verlihub" Website="http://romanticnet.ro/" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="NiceHub - Bv Host" Address="nicehub-bv.no-ip.biz" Secure="" Description="NICEBV BV Romania Bucuresti Shooter Rar Apps mpeg Punk Download avi Covers Games Pictures Comics Rap International Windows HipHop porn Trance TT Chat images Techno Mp3 Music Prison Break Movies Network TV shows divx Gossip Girl Audi" Country="Romania" Encoding="CP1252" Users="249" Operators="6" Bots="4" Clones="2" Infected="6" Shared="168348126285768" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="700" Status="Online" Reliability="95.66" Rating="0" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="KHARKOV_HUB" Address="hub.kharkov.ua:4111" Secure="nmdcs://hub.kharkov.ua:4111" Description="VPS Server от 55 руб / VPS Server from €1,26 &gt;&gt;&gt;&gt;&gt; https://firstbyte.ru/?from=5031/ &lt;&lt;&lt;&lt;&lt;" Country="Ukraine" Encoding="CP1251" Users="235" Operators="1" Bots="5" Clones="17" Infected="5" Shared="198934582764726" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="8000" Status="Online" Reliability="91.14" Rating="-1" Software="Verlihub" Website="" Email="" ASN="Network Management Ltd" Network="" Failover="" Logo="" Icon="https://files.elitedc.ru/ico/915.png" />
		<Hub Name="Отстойник" Address="deep.dchub.su" Secure="" Description="Хаб для забаненых и клонов с других хабов, без правил и цензуры" Country="Soviet Union" Encoding="CP1251" Users="223" Operators="4" Bots="0" Clones="16" Infected="5" Shared="244776468765882" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="5000" Status="Online" Reliability="97.9" Rating="0" Software="PtokaX" Website="" Email="karumo@mail.ru" ASN="Network Management Ltd" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Club-Love -|- I n t e r n a t i o n a l" Address="love.club-fantasy-hub.ro:10" Secure="" Description="Rar Apps mpeg Punk Download avi Covers Pictures Comics Rap International Windows HipHop porn Trance Chat images Techno Mp3 Music Prison Break Movies Network TV shows divx Gossip Girl Audio books PS3 Sound clips Warez mpg Games swiss Grey&apos;s anatomy psp DVD" Country="Romania" Encoding="CP1252" Users="240" Operators="1" Bots="4" Clones="2" Infected="9" Shared="144724173229399" Minshare="1073741824" Minslots="0" Maxhubs="0" Maxusers="10000" Status="Online" Reliability="99.47" Rating="0" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="Club Fantasy Network" Failover="" Logo="" Icon="" />
		<Hub Name="Сеточка" Address="dc.p2p-magnets.ru" Secure="" Description="40RUS &gt;&gt; Нет ограничений &gt;&gt; Добавляй в избранные &gt;&gt; Ты нам нужен." Country="Russian Federation" Encoding="CP1251" Users="231" Operators="4" Bots="0" Clones="4" Infected="3" Shared="188483585853122" Minshare="0" Minslots="1" Maxhubs="0" Maxusers="16000" Status="Online" Reliability="91" Rating="0" Software="PtokaX" Website="http://www.p2p-magnets.ru/" Email="" ASN="RETN Limited" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="TsdHub" Address="tsdhub.info" Secure="" Description="TsdHub" Country="Latvia" Encoding="CP1251" Users="223" Operators="9" Bots="0" Clones="3" Infected="4" Shared="361762262892129" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="93.2" Rating="2" Software="PtokaX" Website="http://tsdhub.info/" Email="" ASN="LLC Baxet" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="BigShare.OVH" Address="bigshare.ovh:1234" Secure="" Description="BigShare.OVH - - &gt; Minimum - - - &gt; 10 GB Share" Country="Romania" Encoding="CP1252" Users="214" Operators="3" Bots="1" Clones="1" Infected="3" Shared="453187453957178" Minshare="10737418240" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="99.7" Rating="0" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="«¤•°MaxiLand°•¤»" Address="dc.pivosik.info" Secure="" Description="° Internet™ Hub °&gt;&gt; MP3 • MOVIES • ISO • RAR • GAMES &lt;&lt; IT&apos;S ALL HERE" Country="Russian Federation" Encoding="CP1251" Users="210" Operators="2" Bots="0" Clones="3" Infected="3" Shared="292868034555800" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="8000" Status="Online" Reliability="99.43" Rating="0" Software="PtokaX" Website="" Email="admin@qplay.ru" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="КошкинДом DCFILES.RU" Address="dc.dcfiles.ru" Secure="" Description="Общение единомышленников, обмен софтом, фильмами и сериалами" Country="Russian Federation" Encoding="CP1251" Users="202" Operators="6" Bots="0" Clones="9" Infected="4" Shared="263893163498376" Minshare="3145728" Minslots="0" Maxhubs="0" Maxusers="500" Status="Online" Reliability="98.98" Rating="0" Software="PtokaX" Website="http://dcfiles.ru/" Email="dcfiles@mail.ru" ASN="YarTV Ltd." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Заячья нора" Address="dc-zayats.ru" Secure="" Description="Zayachiya nora" Country="Russian Federation" Encoding="CP1251" Users="204" Operators="5" Bots="0" Clones="4" Infected="2" Shared="275566028077609" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="99.52" Rating="0" Software="PtokaX" Website="http://dc-zayats.ru/" Email="" ASN="Hosting technology LTD" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="HUB.STOLO.EU" Address="hub.stolo.eu" Secure="" Description="BIG SHARE HUB - 1000 TB÷" Country="Romania" Encoding="CP1252" Users="202" Operators="1" Bots="0" Clones="2" Infected="4" Shared="792815269449132" Minshare="10737418240" Minslots="0" Maxhubs="0" Maxusers="350" Status="Online" Reliability="88.79" Rating="-3" Software="PtokaX" Website="" Email="" ASN="Annarsy SRL" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="=HappyGamers DcHub=" Address="hub.happygamers.eu:8882" Secure="" Description="HappyGamers HighSpeed ULTRA UpSpeed Download Constanta Romania Bucuresti Shooter Rar Apps mpeg Punk Download avi Covers Games Pictures Comics Rap MAC LINUX Windows HipHop porn Trance TT Chat images Techno Mp3 Music Prison Break Movies Network TV shows div" Country="Romania" Encoding="CP1252" Users="193" Operators="4" Bots="3" Clones="1" Infected="7" Shared="196705378433859" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="98.99" Rating="0" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[•PuffñPass--GreenBee`s~Trash-Bin™•]" Address="trash-bin.greenbee.nl:1414" Secure="" Description="" Country="Netherlands" Encoding="CP1252" Users="193" Operators="3" Bots="3" Clones="0" Infected="3" Shared="255109303537603" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="97.61" Rating="4" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="Puff &amp; Pass" Failover="" Logo="" Icon="" />
		<Hub Name="Support Dchublist" Address="support.dchublist.biz:420" Secure="" Description="Support Dchublist.biz" Country="Italy" Encoding="CP1252" Users="181" Operators="2" Bots="3" Clones="0" Infected="0" Shared="227260477672307" Minshare="1073741824" Minslots="0" Maxhubs="1000" Maxusers="2000" Status="Online" Reliability="98.61" Rating="0" Software="Verlihub" Website="" Email="" ASN="ArtPlanet LLC" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="~ E l e c t r o H u B ~" Address="electrohub.ddns.net:888" Secure="" Description="MainInternationalMusicElectronicMinimalDeepTechnoHardstyleHouseTranceChilloutReggaeHardcoreTekAmbientIndustrialGoaPsyDnbLoungeDjDiscogRemixAdultmp3flacDivxXxviDWavItaUkRuRoSexEnBulDanDkSweUsGbChAlDeSpaFinFrHuCzTeeNlGrMxNoZaLLvLtPlSkMcUkJpAuSi" Country="Italy" Encoding="CP1252" Users="178" Operators="17" Bots="1" Clones="3" Infected="3" Shared="244021201697628" Minshare="0" Minslots="1" Maxhubs="350" Maxusers="1000" Status="Online" Reliability="97.5" Rating="40" Software="FlexHub" Website="" Email="" ASN="UAB Rakrejus" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="#BUDAPEST" Address="budapest.sytes.net:1100" Secure="" Description="#### Magyar hub #### Gyere nezz be! #### WELCOME ALL ####" Country="Hungary" Encoding="CP1252" Users="164" Operators="2" Bots="2" Clones="0" Infected="4" Shared="78069060217332" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="95.96" Rating="1" Software="Verlihub" Website="" Email="" ASN="Szervernet Ltd" Network="" Failover="" Logo="https://40felettafoldkorul.hu/wp-content/uploads/2020/09/budapest-card-header-1563434856-760x490.jpg" Icon="https://icons.iconarchive.com/icons/icons8/windows-8/256/City-Cathedral-icon.png" />
		<Hub Name="RETEA2 RDS Timisoara" Address="hub2rds.no-ip.org" Secure="" Description="din Timisoara pentru toata tara!!!" Country="Romania" Encoding="CP1252" Users="174" Operators="0" Bots="2" Clones="0" Infected="5" Shared="28647041030614" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="4000" Status="Online" Reliability="96.92" Rating="10" Software="Verlihub" Website="" Email="" ASN="RCS &amp; RDS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="GELMES" Address="gelmes.net:6666" Secure="" Description="Lietuva" Country="Lithuania" Encoding="CP1252" Users="162" Operators="2" Bots="1" Clones="11" Infected="3" Shared="92796688520972" Minshare="0" Minslots="1" Maxhubs="1000" Maxusers="1000" Status="Online" Reliability="97.54" Rating="2111" Software="FlexHub" Website="" Email="" ASN="OVH SAS" Network="" Failover="dchub://salvija.eu:6666" Logo="" Icon="" />
		<Hub Name="R3vSTAR GAMERS - welcome to new hub , type /fav , in mainchat !" Address="blue.r3volutionstar.com:2411" Secure="" Description="R3vSTAR DOWNLOAD Romania Bucuresti Shooter Rar Apps mpeg Punk Download avi Covers Games Pictures Comics Rap International Windows HipHop porn Trance TT Chat images Techno Mp3 Music Prison Break Movies Network TV shows divx Gossip Girl Audi" Country="Romania" Encoding="CP1252" Users="151" Operators="2" Bots="2" Clones="1" Infected="5" Shared="126654624847925" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="85.12" Rating="1" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="DCHUB.IN.UA" Address="dchub.in.ua" Secure="nmdcs://dchub.in.ua:411" Description="Ukraine Online 24/7 | Alternative ports: 420, 404, 441 | Use secure connection: nmdcs://dchub.in.ua:411 | https://dchub.in.ua/Certificate.zip" Country="Ukraine" Encoding="CP1251" Users="154" Operators="0" Bots="4" Clones="14" Infected="3" Shared="152123191514091" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="3500" Status="Online" Reliability="87.48" Rating="0" Software="Verlihub" Website="http://dchub.in.ua/" Email="" ASN="OVH SAS" Network="" Failover="" Logo="http://ix-ua.net/Incoming/DneiPro)/Centre%2024.12.14.jpg" Icon="http://ix-ua.net/images/upa-14x24.png" />
		<Hub Name="ArbitalHUB" Address="dc.arbital.ru" Secure="" Description="Arbital rulezzzzzzzzzz" Country="Russian Federation" Encoding="CP1251" Users="154" Operators="2" Bots="0" Clones="2" Infected="3" Shared="216493519801033" Minshare="0" Minslots="65535" Maxhubs="65535" Maxusers="5000" Status="Online" Reliability="99.92" Rating="0" Software="Aquila" Website="" Email="" ASN="AS-30083-GO-DADDY-COM-LLC" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Blogietis-Hub" Address="blogietis.no-ip.biz" Secure="" Description="stable international hub work for all world" Country="Lithuania" Encoding="CP1252" Users="138" Operators="2" Bots="3" Clones="1" Infected="4" Shared="378215190656294" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="98.54" Rating="3" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="ХАБикЪ" Address="uahubik.info" Secure="" Description="" Country="Ukraine" Encoding="CP1251" Users="139" Operators="3" Bots="0" Clones="2" Infected="3" Shared="205598752927450" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="0" Status="Online" Reliability="99.5" Rating="0" Software="PtokaX" Website="http://uahub.info/forum/" Email="" ASN="Kyiv Optic Networks ltd" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[byxou] HuB" Address="dc.byxou.ru" Secure="" Description="Welcome!!! 8-)" Country="Russian Federation" Encoding="CP1251" Users="138" Operators="3" Bots="0" Clones="4" Infected="1" Shared="134119840901306" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="32767" Status="Online" Reliability="92.88" Rating="0" Software="PtokaX" Website="" Email="" ASN="Megasvyaz LLC" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Pikenet DC Hub" Address="dc.verlihub.org" Secure="" Description="Pikenet DC Hub. Работает с 21.10.2005." Country="Russian Federation" Encoding="CP1251" Users="134" Operators="0" Bots="5" Clones="3" Infected="3" Shared="118286199401595" Minshare="0" Minslots="0" Maxhubs="20000" Maxusers="6000" Status="Online" Reliability="97.23" Rating="0" Software="Verlihub" Website="http://dc.verlihub.org/" Email="" ASN="PVimpelCom" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[ DC ] *Свобода* SP Hub" Address="freedomsp.ru" Secure="" Description="РКС SPNET - Сергиев Посад / Москва - Мы Работаем Для Вас! ;)" Country="Russian Federation" Encoding="CP1251" Users="129" Operators="1" Bots="0" Clones="5" Infected="4" Shared="179310126061961" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="10000" Status="Online" Reliability="97.66" Rating="0" Software="PtokaX" Website="" Email="" ASN="CSIT LLC" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="-= ХАБ Друзей и Подруг =-" Address="sergsat.ru" Secure="" Description="Хаб для общения друзей , знакомых и просто адекватных людей" Country="Russian Federation" Encoding="CP1251" Users="132" Operators="7" Bots="0" Clones="2" Infected="3" Shared="148545530990368" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="450" Status="Online" Reliability="97.26" Rating="0" Software="PtokaX" Website="" Email="" ASN="Rostelecom" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Laguna-Albastra" Address="laguna.whiteangel.ro:415" Secure="" Description="" Country="Romania" Encoding="CP1250" Users="132" Operators="1" Bots="4" Clones="1" Infected="4" Shared="44421270890012" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="94.38" Rating="1759" Software="Verlihub" Website="" Email="" ASN="Virtono Networks SRL" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[SVERIGE#1][DCHUB.EU][SCANDINAVIAN]" Address="dchub.eu" Secure="" Description="[ABSOLUTE SWEDEN NETWORK]BBB,iso,avi,nrg,mpg,mpeg,xxx,lesbi,porno,hardcore,mp3,Sweden,Poland,Romania,Russia,Hungary,America,Finland,Italy" Country="Sweden" Encoding="CP1252" Users="132" Operators="0" Bots="3" Clones="1" Infected="0" Shared="190239236906098" Minshare="2147483648" Minslots="0" Maxhubs="100" Maxusers="25000" Status="Online" Reliability="96.31" Rating="3" Software="Verlihub" Website="" Email="" ASN="A3 Sverige AB" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="The Play Pen ][Tankerfett Network][" Address="pen.tankafett.biz:4111" Secure="" Description="" Country="Denmark" Encoding="CP1252" Users="129" Operators="6" Bots="4" Clones="0" Infected="0" Shared="147946909811682" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="600" Status="Online" Reliability="97.53" Rating="3" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="Tankafett" Failover="tankafett.biz" Logo="" Icon="" />
		<Hub Name="ТОРТУГА" Address="hub-mahno.ru" Secure="nmdcs://hub-mahno.ru:411" Description="Капитан, позвольте доложить о надвигающемся бунте: я готов называть пальцы и тыкать именами." Country="Russian Federation" Encoding="CP1251" Users="123" Operators="0" Bots="5" Clones="0" Infected="0" Shared="117323118542827" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="20480" Status="Online" Reliability="99.19" Rating="1" Software="Verlihub" Website="" Email="" ASN="IP Ivanov Dmitry Alekseevich" Network="" Failover="" Logo="http://dc.kcahdep.online/logo.jpg" Icon="http://dc.kcahdep.online/favicon.ico" />
		<Hub Name="® TimeZone © Trivia HUB™ - Type /fav in MainChat . For registered nick name type +reg or +ru - have a nice day .... !!!" Address="timezone.yarn.ro" Secure="" Description="TimeZone HUB - enjoy &amp; have fun !! pentru a juca TRIVIA tastati -tin , pentru comenzi tastati -thelp !! «·´`·.(*·.¸(`·.¸ ¸.·´)¸.·*).·´`·» «·´¨*·.¸¸* &amp; Enjoy it *.¸¸.·*¨`·» «·´`·.(¸.·´(¸.·* *·.¸)`·.¸).·´`·» Revista: http://www.ScrieLiber.ro Adresa noastra:" Country="Romania" Encoding="CP1252" Users="120" Operators="0" Bots="3" Clones="1" Infected="5" Shared="68151345738824" Minshare="107374182400" Minslots="0" Maxhubs="1000" Maxusers="2000" Status="Online" Reliability="91.5" Rating="206" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Cool Hub Sharing" Address="dc.focsanivn.ro" Secure="" Description="Bine ai venit ! Viziteaza site-ul oficial www.focsanivn.ro Tasteaza @radio ca sa asculti radio" Country="Romania" Encoding="CP1252" Users="115" Operators="0" Bots="6" Clones="0" Infected="1" Shared="24048567447456" Minshare="1073741824" Minslots="0" Maxhubs="100" Maxusers="600" Status="Online" Reliability="98.65" Rating="68" Software="Verlihub" Website="http://focsanivn.ro/" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Anima Amoris" Address="amoris.sknt.ru" Secure="" Description="Radio station Anima Amoris https://anima.sknt.ru/ No porno" Country="Russian Federation" Encoding="CP1251" Users="111" Operators="4" Bots="0" Clones="5" Infected="3" Shared="138644471059712" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="98.76" Rating="0" Software="PtokaX" Website="http://anima.sknt.ru/" Email="ustserg@nm.ru" ASN="SkyNet Ltd." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="•€V€R-N€T•HUß•" Address="dchub.ever-net.ro" Secure="" Description="Ever-Net Hub ~ No Tough Rules,No More Playing,Just SHARE ~" Country="Romania" Encoding="CP1252" Users="112" Operators="5" Bots="0" Clones="0" Infected="3" Shared="40146080260531" Minshare="5242880000" Minslots="0" Maxhubs="150" Maxusers="10000" Status="Online" Reliability="99.65" Rating="0" Software="Verlihub" Website="http://www.ever-net.ro/" Email="" ASN="M-Tel Consulting SRL" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="• KHV ZONE •" Address="p2p.khvzone.ru" Secure="" Description="Зона свободного файлообмена" Country="Russian Federation" Encoding="CP1251" Users="107" Operators="3" Bots="0" Clones="0" Infected="0" Shared="108065490567325" Minshare="0" Minslots="3" Maxhubs="0" Maxusers="20000" Status="Online" Reliability="91.93" Rating="0" Software="PtokaX" Website="http://www.khvzone.ru/" Email="" ASN="PVimpelCom" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="ROMANIA" Address="servicecafe.ro:699" Secure="" Description="ROMANIA" Country="Romania" Encoding="CP1250" Users="112" Operators="0" Bots="1" Clones="3" Infected="5" Shared="31629115081078" Minshare="0" Minslots="0" Maxhubs="1000" Maxusers="1000" Status="Online" Reliability="99.13" Rating="0" Software="FlexHub" Website="" Email="" ASN="RCS &amp; RDS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="NoName" Address="dc.imsnet.ro" Secure="" Description="Romania-Viteza Gigabit-Conexiune Gigabit-Download-International-Muzica-Trance-House-Mp3-Muzic-Mobile-FiberLink-BigShare-Programe-Mac-Linux-Windows-Image-Iso-Hd-Ro-Dvd-Bluray-Ps3-Games-Apps-Crack-Key-Film" Country="Romania" Encoding="CP1250" Users="111" Operators="0" Bots="2" Clones="1" Infected="3" Shared="32708460096164" Minshare="1073741824" Minslots="0" Maxhubs="0" Maxusers="4000" Status="Online" Reliability="98.49" Rating="0" Software="Verlihub" Website="" Email="" ASN="RCS &amp; RDS" Network="IMS Network" Failover="" Logo="" Icon="" />
		<Hub Name="MichDC.Hub" Address="mich-love.ru:4111" Secure="" Description="Cохраняй адрес нашего хаба: dchub://mich-love.ru:4111 После входа на хаб вводим команду /fav и галочку в &quot;Избранных&quot; напротив нашего хаба" Country="Russian Federation" Encoding="CP1251" Users="113" Operators="4" Bots="0" Clones="3" Infected="2" Shared="117685471203399" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="8000" Status="Online" Reliability="99.33" Rating="0" Software="PtokaX" Website="" Email="pashasv@mail.ru" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="L1stin-HUB" Address="l1stin.mydc.ru" Secure="" Description="Хаб Листин" Country="Russian Federation" Encoding="CP1251" Users="103" Operators="3" Bots="0" Clones="2" Infected="4" Shared="160642687367709" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="500" Status="Online" Reliability="99.29" Rating="0" Software="PtokaX" Website="http://yaroslavlvseti.forumleaks.net/f7-forum" Email="l1stin@mail.ru" ASN="Yarnet Ltd" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="HydrøPønic§-V@ult™" Address="hydroponics-vault.420-net.org:420" Secure="" Description="It&apos;s 4:19 Who&apos;s Got A Min???" Country="United Kingdom" Encoding="CP1252" Users="100" Operators="2" Bots="2" Clones="1" Infected="3" Shared="99039445762822" Minshare="0" Minslots="0" Maxhubs="1000" Maxusers="6000" Status="Online" Reliability="99.91" Rating="0" Software="Verlihub" Website="" Email="" ASN="LeaseWeb Netherlands B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Khimki Quiz - Russia" Address="xumku.org:41111" Secure="" Description="Victorina (Quiz) Khimki.Russia (Old JIuXoXa6 XuMku)" Country="Russian Federation" Encoding="CP1251" Users="109" Operators="4" Bots="0" Clones="1" Infected="2" Shared="101044725352285" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="24999" Status="Online" Reliability="96.84" Rating="0" Software="PtokaX" Website="http://xumku.org/" Email="" ASN="OOO Trivon Networks" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="PlayGround.ru" Address="dc.playground.ru" Secure="" Description="PlayGround.ru DC hub" Country="Russian Federation" Encoding="CP1251" Users="98" Operators="2" Bots="0" Clones="1" Infected="4" Shared="161026495459882" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="98.32" Rating="0" Software="Verlihub" Website="http://www.playground.ru/" Email="" ASN="RopNet" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="SWEDEN - MAIKEN (no share needed)" Address="sweden.maiken.me:333" Secure="" Description="No limit - Free share" Country="Sweden" Encoding="CP1252" Users="101" Operators="1" Bots="0" Clones="2" Infected="6" Shared="125290612787333" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="10000" Status="Online" Reliability="98.64" Rating="0" Software="PtokaX" Website="http://maiken.me/" Email="" ASN="Telenor Norge AS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Основной хаб Томска" Address="p2p.tomsk.ru" Secure="" Description="Качаем и общаемся. Общаемся и качаем." Country="Russian Federation" Encoding="CP1251" Users="103" Operators="2" Bots="0" Clones="1" Infected="2" Shared="106461403505733" Minshare="0" Minslots="3" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="99.13" Rating="0" Software="PtokaX" Website="http://p2p.tomsk.ru/p2p-stata/" Email="" ASN="Rostelecom" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="..:: Hülyék Klubja ::.. - •»[°•°Music Fan&apos;s°•°]«•" Address="musicfans.hopto.org:1208" Secure="" Description="•» Music Fan&apos;s International Hub - Write /fav in the main chat - [HUN] [EU] [RO] [RU] [PL] [ETC..] [MUSIC-MOVIE-XXX-DVD-FULLHD-PROGRAMS-WINDOWS-LINUX-MP3-MP4-AVI-DIVX-RAR-ZIP] - Max users: 1000 - Min Share: 0 Gb - OP/VIP/SHAREVIP - Linux/Verlihub «•" Country="Hungary" Encoding="CP1252" Users="94" Operators="1" Bots="3" Clones="1" Infected="3" Shared="48296334774301" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="96.21" Rating="1" Software="Verlihub" Website="" Email="" ASN="Contabo GmbH" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Мистерия DC Hub" Address="dc.sphub.ru" Secure="" Description="" Country="Russian Federation" Encoding="CP1251" Users="96" Operators="0" Bots="2" Clones="4" Infected="5" Shared="130905648412294" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="92.12" Rating="0" Software="Verlihub" Website="http://sphub.ru/" Email="" ASN="Infotelecom SP Ltd." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Railroad Place" Address="onky.no-ip.org" Secure="" Description="WWE wrestling /music and LOTS!! more" Country="Netherlands" Encoding="CP1252" Users="105" Operators="5" Bots="0" Clones="0" Infected="3" Shared="112010937589101" Minshare="0" Minslots="1" Maxhubs="0" Maxusers="500" Status="Online" Reliability="98.57" Rating="0" Software="PtokaX" Website="" Email="" ASN="Vodafone Libertel B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Jungla HuB" Address="jungla-hub.us.to" Secure="" Description=": : : : : : : : : : &lt;&lt;&lt;&lt; BINE AI VENIT PE HUB &gt;&gt;&gt;&gt; : : : : : : : : : Type /fav in MainChat" Country="Romania" Encoding="CP1252" Users="91" Operators="3" Bots="5" Clones="2" Infected="3" Shared="27868831432076" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="98.99" Rating="178" Software="Verlihub" Website="" Email="" ASN="RCS &amp; RDS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="NobleSSe" Address="noblesse.hub-dc.ro" Secure="" Description="" Country="Romania" Encoding="CP1250" Users="98" Operators="3" Bots="5" Clones="5" Infected="4" Shared="52387796198797" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="58.93" Rating="212" Software="Verlihub" Website="" Email="" ASN="Voxility LLP" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="SmolHUB" Address="dc.smol-hub.net" Secure="" Description="Добро пожаловать на российский DC++ HUB! / Welcome to Russia&apos;s DC + + HUB!" Country="Russian Federation" Encoding="CP1251" Users="95" Operators="1" Bots="0" Clones="6" Infected="2" Shared="107288038493747" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="500" Status="Online" Reliability="99.98" Rating="0" Software="PtokaX" Website="" Email="" ASN="OOO Network of data-centers Selectel" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Семейный Хаб" Address="familyhub.ru" Secure="" Description="YOU ARE WELCOME !!!" Country="Russian Federation" Encoding="CP1251" Users="90" Operators="8" Bots="0" Clones="1" Infected="1" Shared="97752201082294" Minshare="0" Minslots="0" Maxhubs="500" Maxusers="5000" Status="Online" Reliability="97.15" Rating="0" Software="PtokaX" Website="http://familyhub.ru/" Email="" ASN="Octopusnet LTD" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="freeline-hub" Address="v-l.es" Secure="" Description="" Country="Russian Federation" Encoding="CP1251" Users="86" Operators="5" Bots="0" Clones="2" Infected="3" Shared="69780913394552" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="4004" Status="Online" Reliability="93.27" Rating="0" Software="PtokaX" Website="http://v-l.es/" Email="" ASN="Octopusnet LTD" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Добро" Address="goodhub.no-ip.info" Secure="" Description="Добро" Country="Russian Federation" Encoding="CP1251" Users="93" Operators="7" Bots="0" Clones="6" Infected="1" Shared="175196597836014" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="1000" Status="Online" Reliability="96.58" Rating="0" Software="PtokaX" Website="" Email="" ASN="Flex Ltd." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Purgatory - 4" Address="bamboo.comicsfor.me:2015" Secure="" Description="" Country="Canada" Encoding="CP1252" Users="95" Operators="2" Bots="0" Clones="0" Infected="0" Shared="155507892726265" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="0" Status="Online" Reliability="99.78" Rating="0" Software="PtokaX" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="R3volutionSTAR DCHUB" Address="blue.multi-mix.ro:7771" Secure="" Description="UpSpeed Download Constanta R3volutionSTAR Romania Bucuresti Rar Apps mpeg Punk Download avi Covers Pictures Comics Rap International Windows HipHop porn Trance TT Chat images Techno Mp3 Music Prison Break Movies Network TV shows divx Gossip Girl Audi" Country="Romania" Encoding="CP1252" Users="94" Operators="4" Bots="2" Clones="0" Infected="0" Shared="95888413207013" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="98.86" Rating="0" Software="Verlihub" Website="http://multi-mix.ro/" Email="" ASN="OVH SAS" Network="Multi Mix" Failover="" Logo="" Icon="" />
		<Hub Name="Otaku Anime Public" Address="otaku-anime.dchost.eu:555" Secure="" Description="// 1 GB // ANIME // MANGA // HENTAI // AMV // Anime OST // Asian Movies // Jpop //" Country="Antarctica" Encoding="CP1252" Users="93" Operators="1" Bots="2" Clones="2" Infected="2" Shared="210210126336214" Minshare="1073741824" Minslots="1" Maxhubs="100" Maxusers="2000" Status="Online" Reliability="99.78" Rating="0" Software="Verlihub" Website="" Email="" ASN="LeaseWeb Netherlands B.V." Network="Otaku Anime" Failover="" Logo="" Icon="" />
		<Hub Name="[Asgard]CuRZed" Address="curzed.asgards.org:4111" Secure="" Description="TV-Series, Documentaries, Sci-Fi, Fantasy, Legend, Horror, Thriller, Crime, Drama, Comedy." Country="United Kingdom" Encoding="CP1252" Users="92" Operators="11" Bots="4" Clones="0" Infected="0" Shared="97435931462404" Minshare="3221225472" Minslots="0" Maxhubs="1000" Maxusers="1000" Status="Online" Reliability="99.44" Rating="0" Software="FlexHub" Website="" Email="" ASN="Simply Transit Ltd" Network="Asgards" Failover="redirect.curzed.asgards.org" Logo="" Icon="" />
		<Hub Name="DC.Weba.Ru" Address="dc.weba.ru" Secure="" Description="WEBA DC++ HUB" Country="Russian Federation" Encoding="CP1252" Users="83" Operators="0" Bots="3" Clones="1" Infected="3" Shared="57822565712187" Minshare="0" Minslots="0" Maxhubs="1000" Maxusers="15000" Status="Online" Reliability="99.55" Rating="0" Software="Verlihub" Website="https://dc.weba.ru/" Email="" ASN="Seti Weba Ltd" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Питер-Хаб" Address="in.piter-hub.net.ru" Secure="nmdcs://piter-hub.net.ru:411" Description="VPS Server от 55 руб / VPS Server from €1,26 &gt;&gt;&gt;&gt;&gt; https://firstbyte.ru/?from=5031/ &lt;&lt;&lt;&lt;&lt;" Country="Russian Federation" Encoding="CP1251" Users="85" Operators="2" Bots="5" Clones="11" Infected="0" Shared="95802431686285" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="8000" Status="Online" Reliability="78.88" Rating="0" Software="Verlihub" Website="" Email="" ASN="SkyNet Ltd." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="AnimeCrossroads" Address="anime-crossroads.dns2go.com" Secure="" Description="Anime / Manga / Doujinshi / Jpop / OST / MP3 / Games / Japanese Movies" Country="United States" Encoding="CP1252" Users="85" Operators="6" Bots="0" Clones="2" Infected="6" Shared="132939635968042" Minshare="0" Minslots="1" Maxhubs="0" Maxusers="600" Status="Online" Reliability="99.91" Rating="0" Software="PtokaX" Website="" Email="" ASN="DIGITALOCEAN-ASN" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Rock Massive rock-massive.smokendrink.org" Address="music-universe.zapto.org" Secure="" Description="NMDC and ADC users in one hub" Country="Germany" Encoding="CP1252" Users="82" Operators="2" Bots="1" Clones="2" Infected="0" Shared="82282808009301" Minshare="0" Minslots="2" Maxhubs="250" Maxusers="1000" Status="Online" Reliability="90.17" Rating="0" Software="FlexHub" Website="" Email="" ASN="1&amp;1 Ionos Se" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Altair Anime Club" Address="aacnet.zapto.org:10000" Secure="" Description="Anime related stuff" Country="Russian Federation" Encoding="CP1251" Users="77" Operators="4" Bots="0" Clones="2" Infected="2" Shared="167118033493203" Minshare="2147483648" Minslots="1" Maxhubs="0" Maxusers="510" Status="Online" Reliability="97.95" Rating="1" Software="YnHub" Website="" Email="" ASN="PVimpelCom" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="warlords house 2" Address="warlordshouse.no-ip.org" Secure="" Description="Classic Porn_MP3&apos;S_TV Shows_movies_PS2 &amp; PSP Stuff_and more" Country="United States" Encoding="CP1252" Users="84" Operators="4" Bots="0" Clones="1" Infected="3" Shared="287642471734715" Minshare="64424509440" Minslots="2" Maxhubs="0" Maxusers="1500" Status="Online" Reliability="98.28" Rating="39" Software="YnHub" Website="" Email="" ASN="COMCAST-7922" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="..::Białystok.:.Hub::.." Address="whitestok.hostpl.eu:4115" Secure="" Description="...::: Hosted by Hostpl.eu :::... - Największy HUB Podlasia - Serdecznie zapraszamy - http://www.hosting.hostpl.eu" Country="Poland" Encoding="CP1250" Users="83" Operators="0" Bots="3" Clones="2" Infected="0" Shared="32209989720954" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="98.81" Rating="1" Software="Verlihub" Website="" Email="" ASN="SERVERS-COM" Network="Host PL" Failover="" Logo="" Icon="" />
		<Hub Name="The EnigmaT Hub" Address="enigmat.podzone.net" Secure="" Description="Official Radio Rip Hub" Country="United States" Encoding="CP1252" Users="81" Operators="21" Bots="0" Clones="1" Infected="5" Shared="45046555714441" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="3000" Status="Online" Reliability="97.45" Rating="0" Software="YnHub" Website="" Email="" ASN="UUNET" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="HomeNet DC-Hub" Address="new-homes.pp.ua" Secure="" Description="" Country="Ukraine" Encoding="CP1251" Users="75" Operators="3" Bots="0" Clones="1" Infected="4" Shared="51737083376808" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="500" Status="Online" Reliability="78.14" Rating="-1" Software="PtokaX" Website="" Email="" ASN="Content Delivery Network Ltd" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="][M•є•†•a•L][H•µ•Ђ][" Address="metalsamael.rommor.ru:777" Secure="" Description="VPS Server от 55 руб / VPS Server from €1,26 &gt;&gt;&gt;&gt;&gt; https://firstbyte.ru/?from=5031/ &lt;&lt;&lt;&lt;&lt;" Country="Russian Federation" Encoding="CP1251" Users="77" Operators="5" Bots="0" Clones="1" Infected="1" Shared="89262711862452" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="8000" Status="Online" Reliability="93.7" Rating="0" Software="PtokaX" Website="" Email="" ASN="NTX Technologies s.r.o." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Ç£åµÐîµ&amp;Må®¥ • ]-[Úß" Address="claudiu-mary.myftp.biz" Secure="" Description="claudiu-mary.myftp.biz:411" Country="Romania" Encoding="CP1252" Users="78" Operators="1" Bots="4" Clones="1" Infected="3" Shared="36994744986235" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="97.37" Rating="1" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Масяня" Address="masyanya.prapor.in" Secure="" Description="Самый общительный и дружелюбный хаб" Country="Russian Federation" Encoding="CP1251" Users="79" Operators="1" Bots="0" Clones="1" Infected="2" Shared="74477257518198" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="10000" Status="Online" Reliability="95.87" Rating="0" Software="PtokaX" Website="" Email="admin@prapor.in" ASN="Rostelecom" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Krasmediafiles" Address="dc.krasmediafiles.ru" Secure="" Description="Частная Файлообменная Пиринговая Сеть (Россия, г. Красноярск)" Country="Russian Federation" Encoding="CP1251" Users="70" Operators="1" Bots="3" Clones="1" Infected="3" Shared="89691122705668" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="7000" Status="Online" Reliability="95.29" Rating="0" Software="Verlihub" Website="" Email="" ASN="Orion Telecom LLC" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Dutch Friends" Address="dutchfriends.no-ip.org:4112" Secure="" Description="lots of all" Country="Netherlands" Encoding="CP1252" Users="82" Operators="3" Bots="0" Clones="0" Infected="0" Shared="164566362361697" Minshare="5368709120" Minslots="0" Maxhubs="0" Maxusers="2000" Status="Online" Reliability="96.95" Rating="0" Software="PtokaX" Website="" Email="" ASN="Vodafone Libertel B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Daugavpils ODvinsk HuB" Address="hub.odvinsk.ru" Secure="" Description="ODvinsk Team - Daugavpils TRIVIA Hub 24/7 (LV,RUS,ENG)" Country="Latvia" Encoding="CP1251" Users="71" Operators="4" Bots="0" Clones="7" Infected="4" Shared="64236923043768" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="500" Status="Online" Reliability="96.65" Rating="1" Software="PtokaX" Website="http://odvinsk.ru/" Email="support@odvinsk.ru" ASN="DauTKom TV" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="•NICE DOWNLOAD• DcHub" Address="nice.ddnsking.eu:4411" Secure="" Description="•NICE DOWNLOAD• Download Constanta R3volutionSTAR Romania Bucuresti Shooter Rar Apps mpeg Punk Download avi Covers Games Pictures Comics Rap International Windows HipHop porn Trance TT Chat images Techno Mp3 Music Prison Break Movies Network" Country="Romania" Encoding="CP1252" Users="76" Operators="0" Bots="3" Clones="1" Infected="5" Shared="25989069400495" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="97.92" Rating="0" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Untolovo.Net" Address="dchub.untolovo.net" Secure="" Description="" Country="Russian Federation" Encoding="CP1251" Users="68" Operators="1" Bots="2" Clones="1" Infected="3" Shared="76707731244732" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="98.72" Rating="0" Software="Verlihub" Website="http://dchub.untolovo.net/" Email="" ASN="Yunta Ltd." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="MatrixTranceFuZion" Address="matrixtrancefuzion.serveblog.net" Secure="" Description="..:: IF YOU LIKE --!!! TRANCE !!!-- MUSIC STAY TUNED HERE! ::.." Country="Romania" Encoding="CP1252" Users="71" Operators="1" Bots="0" Clones="0" Infected="2" Shared="15896178022878" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="3000" Status="Online" Reliability="95.71" Rating="0" Software="YnHub" Website="http://matrixtrancefuzion.serveblog.net/" Email="" ASN="Liberty Global B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Zalau-Hub" Address="zalauhub.ro" Secure="" Description="" Country="Romania" Encoding="CP1252" Users="78" Operators="1" Bots="4" Clones="1" Infected="4" Shared="33647483186519" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="99.43" Rating="0" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="" Failover="zalau.us.to" Logo="" Icon="" />
		<Hub Name="***Morava-HUB***" Address="olomouc.sytes.net" Secure="" Description="Alternativni porty : 5565 3000 1144 9110 4111 7777" Country="Czech Republic" Encoding="CP1252" Users="69" Operators="2" Bots="0" Clones="1" Infected="6" Shared="99700450402777" Minshare="0" Minslots="0" Maxhubs="999" Maxusers="9999" Status="Online" Reliability="94.84" Rating="0" Software="Verlihub" Website="" Email="" ASN="Master Internet s.r.o." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="PWiAM-HUB" Address="pwiam.hopto.org" Secure="nmdcs://pwiam.hopto.org:411" Description="PWiAM - PL / USA" Country="Poland" Encoding="CP1250" Users="66" Operators="4" Bots="3" Clones="7" Infected="0" Shared="69781931706322" Minshare="1073741824" Minslots="0" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="98.45" Rating="0" Software="Verlihub" Website="" Email="pw.spam.bin@gmail.com" ASN="ATT-INTERNET4" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[Asgard]Venus Prime Corp." Address="vpc.asgards.org" Secure="" Description="[Asgard] Cartoons &amp; SciFi Cap &amp; Distribution Hub" Country="United Kingdom" Encoding="CP1252" Users="68" Operators="5" Bots="1" Clones="0" Infected="1" Shared="173547238009626" Minshare="21474836480" Minslots="0" Maxhubs="1000" Maxusers="1000" Status="Online" Reliability="98.72" Rating="0" Software="FlexHub" Website="http://www.asgards.org/" Email="" ASN="Simply Transit Ltd" Network="Asgards" Failover="redirect.vpc.asgards.org" Logo="" Icon="" />
		<Hub Name="•Love Can Move Mountains•" Address="dc.cane-hub.ro" Secure="" Description="°¨¨°o©©o°¨¨° Love Can Move Mountains°¨¨°o©©o°¨¨° ! ! ! TRIVIA ! ! ! - ! ! ! CHAT ! ! ! - ! ! ! DOWNLOAD ! ! !" Country="Romania" Encoding="CP1252" Users="70" Operators="2" Bots="7" Clones="0" Infected="3" Shared="41884935169273" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="1024" Status="Online" Reliability="97.73" Rating="155" Software="Verlihub" Website="" Email="" ASN="RCS &amp; RDS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="-=[ Dinamo Bucuresti ]=-" Address="fcd.imsnet.ro:1948" Secure="" Description=".:[ INTERNATIONAL HUB ]:.:[ DINAMO BUCHAREST FAN&apos;S ]:." Country="Romania" Encoding="CP1250" Users="67" Operators="0" Bots="3" Clones="1" Infected="5" Shared="29828598477813" Minshare="1073741824" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="98.27" Rating="1" Software="Verlihub" Website="http://hub.servicecafe.ro/" Email="" ASN="RCS &amp; RDS" Network="IMS Network" Failover="" Logo="" Icon="" />
		<Hub Name="MAGYARok-HUBja" Address="magyarok-hubja.dyndns.hu:1848" Secure="" Description="[HUN]Segitokesz tarsasag, rengeteg letöltes, megeri benezni!" Country="Hungary" Encoding="CP1252" Users="62" Operators="4" Bots="0" Clones="0" Infected="2" Shared="32143542189031" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="500" Status="Online" Reliability="95.26" Rating="0" Software="Verlihub" Website="" Email="" ASN="Hetzner Online GmbH" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="ERAZER-NeVedem" Address="167.114.68.89" Secure="" Description="" Country="Romania" Encoding="CP1252" Users="64" Operators="0" Bots="2" Clones="3" Infected="3" Shared="19775610579414" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="94.76" Rating="0" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Paradise и Cmenawka DCHuB" Address="mytula.net" Secure="" Description="Добро пожаловать!" Country="Russian Federation" Encoding="CP1251" Users="64" Operators="1" Bots="0" Clones="1" Infected="1" Shared="82387306105984" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="95.94" Rating="0" Software="PtokaX" Website="" Email="" ASN="PVimpelCom" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Server" Address="kuums.ru" Secure="" Description="Online!" Country="Russian Federation" Encoding="CP1251" Users="66" Operators="2" Bots="0" Clones="1" Infected="2" Shared="49956071728219" Minshare="0" Minslots="0" Maxhubs="65535" Maxusers="500" Status="Online" Reliability="87.68" Rating="1" Software="Verlihub" Website="" Email="" ASN="JSC The First" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="*** P a Z z O M o N d O *** T h E * I n S a N i T a R i U m ***" Address="pazzomondohub.sytes.net" Secure="" Description="TVSeriesEpisodesGOTMarvelBigBangTheoryArrowGrey&apos;sAnatomy2BrokeTeenGirlsTheWalkingDeadTheFlashChicagoFirePDCriminalMindsZooHawaiiFiveOGrimmGothamReignBonesSupernaturalAliasAwkwardAmericanHorrorStory" Country="Italy" Encoding="CP1252" Users="63" Operators="0" Bots="1" Clones="1" Infected="1" Shared="42317387350306" Minshare="0" Minslots="0" Maxhubs="1000" Maxusers="150" Status="Online" Reliability="97.54" Rating="0" Software="FlexHub" Website="" Email="" ASN="UAB Rakrejus" Network="" Failover="dchub://dharmainitiative.sytes.net:2000" Logo="" Icon="" />
		<Hub Name="TwistedGate" Address="twistedgate.thc-network.org:421" Secure="" Description="&apos;][&apos;W][§&apos;][&apos;3Ð•GA&apos;][&apos;3™ ²°°9 The No 1 English Language hub" Country="United Kingdom" Encoding="CP1252" Users="69" Operators="4" Bots="5" Clones="0" Infected="1" Shared="202249071152273" Minshare="1048576" Minslots="0" Maxhubs="100" Maxusers="499" Status="Online" Reliability="97.34" Rating="-1" Software="Verlihub" Website="" Email="" ASN="I.C.S. Trabia-Network S.R.L." Network="THC" Failover="" Logo="" Icon="" />
		<Hub Name="Electron" Address="krossfire.asuscomm.com" Secure="" Description="Hub free for all" Country="Russian Federation" Encoding="CP1251" Users="63" Operators="3" Bots="0" Clones="0" Infected="2" Shared="70070523923285" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="97.62" Rating="0" Software="PtokaX" Website="http://krossfire.asuscomm.com/" Email="" ASN="LLC Electron-Telecom" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="SonarDC" Address="bee.hubdc.ru" Secure="" Description="SonarDC" Country="Russian Federation" Encoding="CP1251" Users="64" Operators="2" Bots="0" Clones="1" Infected="1" Shared="119275944825567" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="200" Status="Online" Reliability="99.86" Rating="0" Software="PtokaX" Website="" Email="" ASN="Global Network Management Inc" Network="Hub DC" Failover="" Logo="" Icon="" />
		<Hub Name="-†-666-The-ONLY-real-number-†-" Address="666homeofstrongest.ddns.net:420" Secure="" Description="Metal , in any kind =)" Country="Germany" Encoding="CP1252" Users="61" Operators="19" Bots="0" Clones="0" Infected="2" Shared="244185804806363" Minshare="0" Minslots="2" Maxhubs="250" Maxusers="1000" Status="Online" Reliability="98.07" Rating="-1" Software="PtokaX" Website="" Email="thunderbolda10a@gmx.de" ASN="GleSYS AB" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="F£orãéñFãúñã" Address="floraenfauna.no-ip.info" Secure="" Description="NED[NL][BE][ENG][USA][SWE][RO][NOR][DE][BBB][100Mbit]Dutch//Anime,Manga,Music,Movies,G Leviathan v4.1[FINAL]" Country="Netherlands" Encoding="CP1252" Users="66" Operators="9" Bots="0" Clones="0" Infected="2" Shared="239566795566547" Minshare="26214400" Minslots="0" Maxhubs="0" Maxusers="5000" Status="Online" Reliability="96.82" Rating="0" Software="PtokaX" Website="" Email="" ASN="KPN B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="BraBlay DC Hub" Address="brablay.spb.ru:4111" Secure="" Description="" Country="Russian Federation" Encoding="CP1251" Users="64" Operators="2" Bots="0" Clones="1" Infected="2" Shared="84402609252462" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="99.42" Rating="0" Software="PtokaX" Website="" Email="sinta-cs@mail.ru" ASN="SkyNet Ltd." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="ASP-HUB" Address="hub.volia.pp.ua" Secure="" Description="Добро пожаловать на ASP-HUB!" Country="Ukraine" Encoding="CP1251" Users="63" Operators="3" Bots="0" Clones="0" Infected="1" Shared="64983454061699" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="6000" Status="Online" Reliability="96.65" Rating="0" Software="Verlihub" Website="" Email="" ASN="PJSC Ukrtelecom" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="OldHouse DC" Address="dc.oldhouse.ws" Secure="" Description="Moscow Area DC File Server" Country="Russian Federation" Encoding="CP1251" Users="59" Operators="1" Bots="0" Clones="1" Infected="4" Shared="69685703706690" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="500" Status="Online" Reliability="97.38" Rating="1" Software="PtokaX" Website="" Email="" ASN="Beirel Telecom LLC" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="• L D Z • d c h u b • p l" Address="lodz.dchub.pl:1423" Secure="nmdcs://lodz.dchub.pl:1423" Description="hosted by DCHUB.PL" Country="Poland" Encoding="CP1252" Users="63" Operators="2" Bots="4" Clones="1" Infected="0" Shared="22796473835359" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="99.17" Rating="0" Software="Verlihub" Website="" Email="" ASN="Nazwa.pl Sp.z.o.o." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="..:::MEZCIEMS:::.." Address="mezciems.no-ip.org" Secure="" Description="Mezciems hub" Country="Latvia" Encoding="CP1251" Users="57" Operators="3" Bots="0" Clones="3" Infected="3" Shared="43223962858005" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="5000" Status="Online" Reliability="99.63" Rating="0" Software="PtokaX" Website="" Email="" ASN="SIA Baltcom" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Antimanele_HUB" Address="antimanele.hmr.ro" Secure="" Description="Hub Antimanele. Hub preferat ai celor ce vor sa asculte muzica de calitate!" Country="Romania" Encoding="CP1252" Users="66" Operators="0" Bots="3" Clones="0" Infected="3" Shared="32096456306849" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="97.94" Rating="6" Software="Verlihub" Website="https://antimanele.hmr.ro/" Email="" ASN="RCS &amp; RDS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="SunGate DC++ Hub" Address="dc.sungate.su" Secure="" Description="SunGate DC++ Hub (Russia, Kaluga region)" Country="Soviet Union" Encoding="CP1251" Users="50" Operators="0" Bots="1" Clones="1" Infected="2" Shared="51465366092156" Minshare="0" Minslots="0" Maxhubs="1000" Maxusers="10000" Status="Online" Reliability="94.8" Rating="0" Software="SunGateDCH" Website="http://dc.sungate.su/" Email="" ASN="Hetzner Online GmbH" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="menorcasvr.synology.me" Address="menorcasvr.synology.me" Secure="" Description="Hub Publico Free search &amp; Download NMDC and ADC users in one hub" Country="Spain" Encoding="CP1252" Users="57" Operators="3" Bots="1" Clones="1" Infected="0" Shared="314975168764758" Minshare="0" Minslots="0" Maxhubs="999" Maxusers="20000" Status="Online" Reliability="90.05" Rating="0" Software="FlexHub" Website="" Email="hubdc@hotmail.com" ASN="Telefonica De Espana" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Johtajan Hubi" Address="johtajat.no-ip.org" Secure="" Description="Paskasta se kukkanenkin kasvaa" Country="Finland" Encoding="CP1252" Users="57" Operators="12" Bots="0" Clones="0" Infected="2" Shared="16732721882355" Minshare="0" Minslots="0" Maxhubs="65535" Maxusers="1000" Status="Online" Reliability="98.84" Rating="0" Software="Aquila" Website="http://johtajat.no-ip.org/" Email="" ASN="Mythic Beasts Ltd" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Motya Hub" Address="motya.prapor.in" Secure="" Description="Мотя хаб - Общение без цензуры (18+)" Country="Russian Federation" Encoding="CP1251" Users="53" Operators="1" Bots="0" Clones="1" Infected="0" Shared="79271669414276" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="10000" Status="Online" Reliability="83.45" Rating="0" Software="PtokaX" Website="" Email="admin@prapor.in" ASN="OJSC Comcor" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="hublist.org.nz" Address="hublist.org.nz:412" Secure="" Description="An ADC or NMDC Hub. Legal porn ONLY. Check all files and filenames BEFORE you share them." Country="New Zealand" Encoding="CP1252" Users="59" Operators="4" Bots="1" Clones="0" Infected="0" Shared="379792830899795" Minshare="1073741824" Minslots="1" Maxhubs="300" Maxusers="500" Status="Online" Reliability="98.63" Rating="0" Software="FlexHub" Website="http://hublist.org.nz/" Email="redrider@snap.net.nz" ASN="Snap Internet Limited" Network="" Failover="dd.tankafett.biz" Logo="" Icon="" />
		<Hub Name="KMV" Address="kmv-hub.tk" Secure="" Description="Private hub" Country="Russian Federation" Encoding="CP1251" Users="59" Operators="3" Bots="3" Clones="0" Infected="1" Shared="173797586112116" Minshare="1048576" Minslots="0" Maxhubs="0" Maxusers="20000" Status="Online" Reliability="94.23" Rating="0" Software="Verlihub" Website="http://kmv-hub.tk/" Email="" ASN="PVimpelCom" Network="KMV" Failover="" Logo="" Icon="" />
		<Hub Name="Russian Extreme Hub" Address="extremehub.elitedc.ru" Secure="" Description="VPS Server от 55 руб / VPS Server from €1,26 &gt;&gt;&gt;&gt;&gt; https://firstbyte.ru/?from=5031/ &lt;&lt;&lt;&lt;&lt;" Country="Russian Federation" Encoding="CP1251" Users="60" Operators="3" Bots="0" Clones="0" Infected="3" Shared="66608383995483" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="10000" Status="Online" Reliability="98.56" Rating="2" Software="PtokaX" Website="" Email="ksenia1944@yandex.ru" ASN="Network Management Ltd" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="&lt;siava.ru&gt;" Address="siava.ru" Secure="" Description="&lt;Hub of the Sertolovo City&gt;" Country="Russian Federation" Encoding="CP1251" Users="50" Operators="1" Bots="0" Clones="1" Infected="0" Shared="72852228158798" Minshare="0" Minslots="1" Maxhubs="0" Maxusers="25500" Status="Online" Reliability="99.59" Rating="0" Software="PtokaX" Website="https://siava.ru/" Email="admin@siava.ru" ASN="SkyNet Ltd." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="~TriBuL VeSeL~" Address="dc.indian-world.us.to" Secure="" Description="°°°Adresa noastrã este : » dchub://dc.indian-world.us.to:411 «" Country="Romania" Encoding="CP1252" Users="60" Operators="3" Bots="6" Clones="0" Infected="2" Shared="12882768245983" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="300" Status="Online" Reliability="99.1" Rating="8" Software="Verlihub" Website="http://indian-world.us.to/" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="»-([:-•GLADIATOR•HUB•-:])-«" Address="gladiatorhub.no-ip.hu:5030" Secure="" Description="" Country="Hungary" Encoding="CP1252" Users="51" Operators="6" Bots="0" Clones="0" Infected="1" Shared="27085963390195" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="500" Status="Online" Reliability="99.51" Rating="0" Software="Verlihub" Website="" Email="" ASN="Hetzner Online GmbH" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="-=ROOTZ-DCHUB=-" Address="roootz.multi-mix.ro:2908" Secure="" Description="ROOTZ GAMES International HuB Romania Bucuresti Rar Apps mpeg Punk Download avi Covers Pictures Comics Rap International Windows HipHop DOWNLOAD Trance Chat images Techno Mp3 Music Prison Break Movies Network TV shows divx Gossip Girl Audi" Country="Romania" Encoding="CP1252" Users="51" Operators="1" Bots="2" Clones="1" Infected="3" Shared="25291396793922" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="93.25" Rating="0" Software="Verlihub" Website="http://multi-mix.ro/" Email="" ASN="Aruba S.p.A." Network="Multi Mix" Failover="" Logo="" Icon="" />
		<Hub Name="MLK-Network" Address="mlk27.go.ro" Secure="" Description="" Country="Romania" Encoding="CP1252" Users="53" Operators="0" Bots="2" Clones="0" Infected="4" Shared="20664043118093" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="95.22" Rating="0" Software="Verlihub" Website="" Email="" ASN="RCS &amp; RDS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Houba lesni" Address="houbalesni.mujsrv.cz:4111" Secure="" Description="" Country="Czech Republic" Encoding="CP1252" Users="53" Operators="8" Bots="0" Clones="0" Infected="3" Shared="92413462431455" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="95.89" Rating="0" Software="PtokaX" Website="http://mujsrv.cz/" Email="" ASN="Sys-DataCom s.r.o." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Private.Hub" Address="private.servicecafe.ro:999" Secure="" Description="Romania-Viteza Gigabit-Conexiune Gigabit-Download-International-Muzica-Trance-House-Mp3-Muzic-Mobile-FiberLink-BigShare-Programe-Mac-Linux-Windows-Image-Iso-Hd-Ro-Dvd-Bluray-Ps3-Games-Apps-Crack-Key-Film" Country="Romania" Encoding="CP1250" Users="57" Operators="0" Bots="2" Clones="2" Infected="4" Shared="27169083459814" Minshare="5368709120" Minslots="0" Maxhubs="0" Maxusers="4000" Status="Online" Reliability="99.28" Rating="0" Software="Verlihub" Website="" Email="" ASN="RCS &amp; RDS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Формула Связи DC++ Хаб" Address="dc.iformula.ru" Secure="" Description="Статистика: http://dc.iformula.ru" Country="Russian Federation" Encoding="CP1251" Users="50" Operators="1" Bots="0" Clones="2" Infected="1" Shared="53502229215718" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="1500" Status="Online" Reliability="97.92" Rating="0" Software="PtokaX" Website="http://dc.iformula.ru/" Email="support@iformula.ru" ASN="Kvartal Plus Ltd" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[NL]Holland Actief 6." Address="ha6.no-ip.org:644" Secure="" Description="-(¯ ·.¸¸.-® AcTiefNetWork. ®-.¸¸.·´¯)-nederlandvdutch,mp3mpgavisogames,videomusicountrytrancemetalfilmhiphop,BE,Nederlandse gezelligheids hub RCv10.023" Country="Netherlands" Encoding="CP1252" Users="56" Operators="9" Bots="0" Clones="1" Infected="1" Shared="61449526060639" Minshare="51200" Minslots="1" Maxhubs="0" Maxusers="500" Status="Online" Reliability="94.93" Rating="0" Software="PtokaX" Website="" Email="" ASN="T-mobile Netherlands B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Anime Unlimited" Address="animeunlimited.no-ip.com" Secure="" Description="Anime, Games, Movies, Music, Programs and so Much More....... Please enjoy your stay!" Country="United States" Encoding="CP1252" Users="52" Operators="7" Bots="0" Clones="0" Infected="0" Shared="106542624153910" Minshare="1073741824" Minslots="1" Maxhubs="60" Maxusers="80" Status="Online" Reliability="99.11" Rating="4" Software="PtokaX" Website="" Email="" ASN="PBNET" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Rubinplus.net" Address="dc.rubinplus.net" Secure="" Description="" Country="Ukraine" Encoding="CP1251" Users="50" Operators="3" Bots="0" Clones="1" Infected="2" Shared="30762234070326" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="300" Status="Online" Reliability="93.2" Rating="0" Software="PtokaX" Website="https://rubintele.com/" Email="" ASN="Teleradiocompany RubinTelecom Ltd." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="BigShareDС++ Hub" Address="bigshare.pp.ua" Secure="" Description="Для входа на хаб, вы должны иметь минимум 100GB шары." Country="Russian Federation" Encoding="CP1251" Users="52" Operators="3" Bots="0" Clones="1" Infected="1" Shared="101985257871947" Minshare="107374182400" Minslots="0" Maxhubs="0" Maxusers="8001" Status="Online" Reliability="98.21" Rating="0" Software="PtokaX" Website="" Email="" ASN="NTX Technologies s.r.o." Network="" Failover="" Logo="https://www.megalive.pp.ua/images/megalivelogo.png" Icon="https://www.megalive.pp.ua/faviconn.png" />
		<Hub Name="Madhub" Address="pman.mine.nu" Secure="" Description="Madhub" Country="Hungary" Encoding="CP1250" Users="50" Operators="2" Bots="0" Clones="1" Infected="0" Shared="57752370767568" Minshare="4294967296" Minslots="2" Maxhubs="0" Maxusers="3000" Status="Online" Reliability="97.95" Rating="0" Software="YnHub" Website="" Email="" ASN="Liberty Global B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="B.E.S.T - H.U.B" Address="dc.besthub.ru" Secure="" Description="VPS Server от 55 руб / VPS Server from €1,26 &gt;&gt;&gt;&gt;&gt; https://firstbyte.ru/?from=5031/ &lt;&lt;&lt;&lt;&lt;" Country="Russian Federation" Encoding="CP1251" Users="52" Operators="4" Bots="0" Clones="0" Infected="1" Shared="31284728057278" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="8000" Status="Online" Reliability="100" Rating="0" Software="PtokaX" Website="" Email="info@besthub.ru" ASN="Network Management Ltd" Network="" Failover="" Logo="https://www.megalive.su/images/logo.png" Icon="https://www.megalive.su/favicon.ico" />
		<Hub Name="**«•*][­][*A*J*N*A*L*Cs*I*L*L*A*G*•»**" Address="kyaranet.org:1984" Secure="" Description="[HUN] Várunk a legfényesebb csillagon" Country="Hungary" Encoding="CP1252" Users="47" Operators="3" Bots="0" Clones="0" Infected="3" Shared="20823147531595" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="500" Status="Online" Reliability="89.98" Rating="0" Software="Verlihub" Website="" Email="" ASN="Hetzner Online GmbH" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="..::FAThub::.. V2.0" Address="fathub.ru" Secure="" Description="Old FAThub Reborned" Country="Russian Federation" Encoding="CP1251" Users="52" Operators="1" Bots="0" Clones="0" Infected="2" Shared="51272963472364" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="31337" Status="Online" Reliability="86.97" Rating="0" Software="PtokaX" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[NL LEKKERHOLLANDS2 -" Address="holland2.hopto.org" Secure="" Description="Network Dutch Division: MUSIC GAMES MOVIES PORN DVD XBOX PS2 NINTENDO XXX NL NEDERLANDS DUTCH HOLLAND NETHERLANDS BE ENG SWE FIN HUN USA TELIA BBB RO RUMANIAN" Country="Netherlands" Encoding="CP1252" Users="49" Operators="2" Bots="0" Clones="0" Infected="1" Shared="30972530929172" Minshare="0" Minslots="1" Maxhubs="400" Maxusers="750" Status="Online" Reliability="88.57" Rating="0" Software="Eximius" Website="http://holland2.hopto.org/" Email="" ASN="Vodafone Libertel B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="SvetogorskBB" Address="enso.pro" Secure="" Description="" Country="Russian Federation" Encoding="CP1251" Users="47" Operators="0" Bots="3" Clones="1" Infected="2" Shared="41642042946632" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="97.04" Rating="0" Software="Verlihub" Website="" Email="" ASN="OOO Network of data-centers Selectel" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="R.E.A.L.I.T.Y.-H.U.B." Address="reality.bucihost.net:4220" Secure="" Description="[HUN] [No Limit] [YokoFm Radio http://s30.myradiostream.com:31164/listen.pls ] [Port: 4220]" Country="Hungary" Encoding="CP1252" Users="48" Operators="3" Bots="0" Clones="0" Infected="2" Shared="16726878368605" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="6000" Status="Online" Reliability="99.84" Rating="0" Software="Verlihub" Website="" Email="" ASN="Hetzner Online GmbH" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Platinum-Hub" Address="dc.agropeople.ru" Secure="" Description="Main Russian Hub-No Rules No Limits" Country="Russian Federation" Encoding="CP1251" Users="49" Operators="1" Bots="2" Clones="1" Infected="3" Shared="44547474748555" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="98.88" Rating="1" Software="Verlihub" Website="" Email="" ASN="Belcloud LTD" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Sutemos" Address="dc.sutemos.lt:9999" Secure="" Description="Electronic / Folk / Ambient / Psy / Chill / Drum and Bass [DnB] / Neurofunk / Techno Music. Lietuva" Country="Lithuania" Encoding="CP1252" Users="46" Operators="2" Bots="1" Clones="2" Infected="2" Shared="36539977288529" Minshare="0" Minslots="1" Maxhubs="1000" Maxusers="1000" Status="Online" Reliability="89.4" Rating="1011" Software="FlexHub" Website="http://dc.sutemos.lt/" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="HUB Hoinareala" Address="hub.hoinareala.eu" Secure="" Description="Hoinarim prin viata" Country="Romania" Encoding="CP1252" Users="51" Operators="0" Bots="3" Clones="1" Infected="3" Shared="26011905689748" Minshare="1073741824" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="98.9" Rating="0" Software="Verlihub" Website="http://hoinareala.eu/" Email="" ASN="Telekom Romania Communication S.A" Network="" Failover="" Logo="" Icon="http://hoinareala.eu/logo_hoinareala_color.png" />
		<Hub Name="[KVN]•Da Beertje Reggae Tavern•" Address="reggaetavern.no-ip.info:3000" Secure="" Description="Reggae music/videos Leviathan™ 2nd Generation v. 1.4" Country="Netherlands" Encoding="CP1252" Users="45" Operators="5" Bots="0" Clones="0" Infected="0" Shared="84265970208549" Minshare="26843545600" Minslots="0" Maxhubs="100" Maxusers="500" Status="Online" Reliability="98.03" Rating="8" Software="PtokaX" Website="" Email="" ASN="KPN B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Slo•M€&apos;][&apos;ÂL•ROÇK••ÇÂ§†L€•" Address="metalcastle.si:11112" Secure="" Description="Metal,Gothic,Doom,Death,Black,Folk,Gore,Grind,Crust,Viking,Heavy,Hard Rock,Punk...[SLoVeNIa][Eu]" Country="Slovenia" Encoding="CP1252" Users="48" Operators="9" Bots="0" Clones="0" Infected="0" Shared="161975693252740" Minshare="10737418240" Minslots="1" Maxhubs="0" Maxusers="500" Status="Online" Reliability="96.09" Rating="182" Software="PtokaX" Website="http://metalcastle.si/" Email="" ASN="Telekom Slovenije, d.d." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Logovo -=Padonka=-" Address="dc.drivesource.ru" Secure="" Description="www.drivesource.ru" Country="Russian Federation" Encoding="CP1251" Users="47" Operators="3" Bots="0" Clones="1" Infected="2" Shared="73769848655982" Minshare="2147483648" Minslots="1" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="93.66" Rating="0" Software="PtokaX" Website="http://www.drivesource.ru/" Email="padonak@padonak.su" ASN="Central Telegraph Public Joint-stock Company" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="ø,¸¸,ø¤º`°º¤ø,¸ L&apos;antre des dragons ¸,ø¤º°`°º¤ø,¸¸,ø" Address="dragonfires.ddns.net:800" Secure="" Description="Le Partage Avant Tout" Country="France" Encoding="CP1252" Users="48" Operators="5" Bots="0" Clones="0" Infected="0" Shared="223806141544720" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="500" Status="Online" Reliability="90.82" Rating="43" Software="PtokaX" Website="" Email="" ASN="Shpv France SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Doctor&amp;Julia HuB" Address="188.42.62.151:2020" Secure="" Description="Doctor&amp;Julia HuB &lt;&gt;SERDECZNIE ZAPRASZA&lt;&gt;" Country="Poland" Encoding="CP1252" Users="44" Operators="3" Bots="3" Clones="5" Infected="3" Shared="52009168818975" Minshare="1074790400" Minslots="0" Maxhubs="0" Maxusers="100" Status="Online" Reliability="99.86" Rating="0" Software="Verlihub" Website="" Email="" ASN="SERVERS-COM" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Mythbusters hub" Address="devil185.no-ip.org" Secure="" Description="" Country="Russian Federation" Encoding="CP1251" Users="47" Operators="6" Bots="0" Clones="2" Infected="0" Shared="58568056990165" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="95.68" Rating="0" Software="PtokaX" Website="" Email="c36ntm5f@yandex.ru" ASN="PVimpelCom" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="FX Hub" Address="fxhub.ru" Secure="" Description="&quot;Sakhalin FX DC Hub. [ fxhub.ru | http://talkers.ru ]&quot;" Country="Russian Federation" Encoding="CP1251" Users="45" Operators="2" Bots="0" Clones="0" Infected="1" Shared="53199359313130" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="6000" Status="Online" Reliability="98.43" Rating="0" Software="Verlihub" Website="" Email="" ASN="LLC Sakh.TV" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="T h e D h a r m a I n i t i a t i v e P r o j e c t" Address="dharmainitiative.sytes.net:2000" Secure="" Description="TVSeriesEpisodesGOTMarvelBigBangTheoryArrowGrey&apos;sAnatomy2BrokeTeenGirlsTheWalkingDeadTheFlashChicagoFirePDCriminalMindsZooHawaiiFiveOGrimmGothamReignBonesSupernaturalAliasAwkwardAmericanHorrorStory" Country="Lithuania" Encoding="CP1252" Users="39" Operators="1" Bots="1" Clones="1" Infected="2" Shared="29632561379275" Minshare="0" Minslots="0" Maxhubs="1000" Maxusers="150" Status="Online" Reliability="97.51" Rating="1" Software="FlexHub" Website="" Email="" ASN="UAB Rakrejus" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="IRON MAIDEN" Address="ironmaiden.odysejahub.com:1090" Secure="" Description="NMDC and ADC users in one hub" Country="Poland" Encoding="CP1252" Users="46" Operators="1" Bots="1" Clones="1" Infected="2" Shared="21306590820140" Minshare="0" Minslots="0" Maxhubs="1000" Maxusers="1000" Status="Online" Reliability="96.63" Rating="0" Software="FlexHub" Website="" Email="" ASN="LeaseWeb Netherlands B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Point Pleasant" Address="pointpleasant.ddns.net" Secure="" Description="The home of MothMan" Country="Finland" Encoding="CP1252" Users="43" Operators="11" Bots="0" Clones="0" Infected="1" Shared="71426138320153" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="96.15" Rating="0" Software="PtokaX" Website="" Email="" ASN="Host Sailor Ltd" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Direct Connect" Address="hub.dc24h.eu:2021" Secure="" Description="Welcome all users from Europe." Country="Europe" Encoding="CP1252" Users="44" Operators="1" Bots="3" Clones="0" Infected="0" Shared="8948220570394" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="500" Status="Online" Reliability="99.88" Rating="0" Software="Verlihub" Website="" Email="" ASN="home.pl S.A." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Адмиралтейский хаб" Address="admiralhub.ru" Secure="nmdcs://admiralhub.ru:411" Description="Хостинг и VPS Server от 150 руб https://firstbyte.ru/?from=5031/ https://firstbyte.ru/?from=76347/" Country="Russian Federation" Encoding="CP1251" Users="45" Operators="2" Bots="4" Clones="4" Infected="2" Shared="80623827365497" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="8000" Status="Online" Reliability="81.01" Rating="0" Software="Verlihub" Website="" Email="" ASN="Network Management Ltd" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="ÜndèrGrøund® Hømè" Address="home.udgnet.com:7778" Secure="" Description="ÜndèrGrøund® Ñètwø®k as always" Country="Sweden" Encoding="CP1252" Users="41" Operators="1" Bots="1" Clones="1" Infected="1" Shared="29402781151208" Minshare="0" Minslots="1" Maxhubs="1000" Maxusers="1000" Status="Online" Reliability="98.26" Rating="0" Software="FlexHub" Website="http://udgnet.com/" Email="en_dator@udgnet.com" ASN="Olofstroms Kabel-TV AB" Network="Underground Network" Failover="dchub://dumphub.udgnet.com:714" Logo="" Icon="" />
		<Hub Name="~~&gt;Пустыня&lt;~~" Address="ilya.pp.ua:666" Secure="" Description="UTF-8 EiskaltDC++ GNU/Linux openSUSE KDE Харьков Пустынный Круглосуточный" Country="Ukraine" Encoding="UTF-8" Users="42" Operators="2" Bots="0" Clones="0" Infected="0" Shared="22664008465594" Minshare="0" Minslots="1" Maxhubs="0" Maxusers="32767" Status="Online" Reliability="73.09" Rating="0" Software="PtokaX" Website="https://ilya.pp.ua/" Email="ilya@ilya.pp.ua" ASN="Ltd. Cypher" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="AnimeHub.ru" Address="animehub.ru" Secure="" Description="&quot;anime, manga, fanart, artbook, hentai&quot;" Country="Russian Federation" Encoding="CP1251" Users="45" Operators="1" Bots="4" Clones="0" Infected="0" Shared="352917891547411" Minshare="10737418240" Minslots="1" Maxhubs="40" Maxusers="1000" Status="Online" Reliability="98.59" Rating="1" Software="Verlihub" Website="http://animehub.ru/" Email="" ASN="JSC ER-Telecom Holding" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="SIP46 DC++ Рыбинск" Address="pennas.servequake.com" Secure="" Description="г.Рыбинск (ттк)" Country="Russian Federation" Encoding="CP1251" Users="42" Operators="2" Bots="0" Clones="0" Infected="1" Shared="70882429752246" Minshare="0" Minslots="1" Maxhubs="0" Maxusers="200" Status="Online" Reliability="95.51" Rating="1" Software="PtokaX" Website="http://yaroslavlvseti.forumleaks.net/f20-forum" Email="aleksandr.lap@mail.ru" ASN="ATEXS PLUS Ltd." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Akropolis hub" Address="akropolis.hopto.org:2004" Secure="" Description="[HUN][EU]•[Check it out, you do not minD] »•»AkRoPoLiS•CLuß«•« [No Min.Share]•[MP3]•[VideO]•[MobilE]•" Country="Hungary" Encoding="CP1252" Users="39" Operators="1" Bots="2" Clones="0" Infected="2" Shared="27412499360862" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="500" Status="Online" Reliability="98.11" Rating="0" Software="Verlihub" Website="" Email="" ASN="Contabo GmbH" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="-=Hubertus=-" Address="hubertus.dyndns.hu:3432" Secure="" Description="" Country="Hungary" Encoding="CP1252" Users="37" Operators="5" Bots="0" Clones="0" Infected="1" Shared="15748192272919" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="500" Status="Online" Reliability="98.71" Rating="0" Software="Verlihub" Website="" Email="" ASN="Hetzner Online GmbH" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Банзай хаб" Address="udo-hub.tk" Secure="" Description="" Country="Ukraine" Encoding="CP1251" Users="45" Operators="3" Bots="0" Clones="1" Infected="2" Shared="133478358589861" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="400" Status="Online" Reliability="69.31" Rating="0" Software="PtokaX" Website="" Email="" ASN="WildPark Co" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="nemesis" Address="dc.agent79.org:1411" Secure="" Description="NMDC and ADC users in one hub" Country="United States" Encoding="CP1252" Users="40" Operators="1" Bots="2" Clones="1" Infected="2" Shared="39828662855940" Minshare="0" Minslots="0" Maxhubs="1000" Maxusers="1000" Status="Online" Reliability="92.72" Rating="0" Software="FlexHub" Website="https://agent79.org/" Email="" ASN="WCENTRALN" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="FIFA Romania HUB" Address="fifaromania.servebeer.com:2007" Secure="" Description="FIFA Romania Offical HUB" Country="Romania" Encoding="CP1252" Users="41" Operators="1" Bots="0" Clones="0" Infected="1" Shared="20742173599702" Minshare="0" Minslots="0" Maxhubs="255" Maxusers="5000" Status="Online" Reliability="91.65" Rating="2" Software="HeXHub" Website="" Email="cortina_hubs@yahoo.com" ASN="RCS &amp; RDS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="NLN" Address="nln.no-ip.org" Secure="" Description="PeLink Hub" Country="Russian Federation" Encoding="CP1251" Users="41" Operators="2" Bots="0" Clones="1" Infected="0" Shared="80867844359746" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="1500" Status="Online" Reliability="89.86" Rating="0" Software="PtokaX" Website="" Email="" ASN="Megasvyaz LLC" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Allround Music Hub" Address="allroundmusic.no-ip.org" Secure="" Description="NMDC and ADC users in one hub" Country="Netherlands" Encoding="CP1252" Users="43" Operators="2" Bots="1" Clones="0" Infected="2" Shared="42507478310834" Minshare="0" Minslots="2" Maxhubs="1000" Maxusers="750" Status="Online" Reliability="93.6" Rating="0" Software="FlexHub" Website="" Email="" ASN="Vodafone Libertel B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="MiMic HUB" Address="adc.mimic.cz:1511" Secure="" Description="Czech ADC/NMDC Hub" Country="Czech Republic" Encoding="CP1252" Users="42" Operators="1" Bots="1" Clones="0" Infected="1" Shared="10522150434510" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="0" Status="Online" Reliability="99.39" Rating="0" Software="FlexHub" Website="http://mimic.cz/" Email="" ASN="WEDOS Internet, a.s." Network="" Failover="adc://uhub.mimic.cz:1515" Logo="" Icon="" />
		<Hub Name="[NL]Holland Actief 2." Address="ha2.no-ip.org" Secure="" Description="-(¯ ·.¸¸.-® AcTiefNetWork. ®-.¸¸.·´¯)-nederlandvdutch,mp3mpgavisogames,videomusicountrytrancemetalfilmhiphop,BE,Nederlandse gezelligheids hub RCv10.023" Country="Netherlands" Encoding="CP1252" Users="46" Operators="9" Bots="0" Clones="2" Infected="1" Shared="34277320530448" Minshare="1073741824" Minslots="1" Maxhubs="0" Maxusers="538" Status="Online" Reliability="94.98" Rating="0" Software="PtokaX" Website="" Email="" ASN="T-mobile Netherlands B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="GeekHuB" Address="hub.geekhost.ro" Secure="" Description="For hosting contact [RO]PixeL" Country="Romania" Encoding="CP1252" Users="40" Operators="2" Bots="2" Clones="0" Infected="1" Shared="15764307430982" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="99.16" Rating="1" Software="Verlihub" Website="" Email="" ASN="RCS &amp; RDS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[SWE]Stabilt" Address="piggelin.myftp.org:7643" Secure="" Description="2021-04-20 12:34:15 Endast SWE ISP, BBB/Telia/Ownit/HSB/Bolina/MKB/Glocalnet/Comhem/Labs2/B²/Chello/SuNET/Bahnhof/Tele2/TDC/ADamo" Country="Sweden" Encoding="CP1252" Users="43" Operators="1" Bots="0" Clones="0" Infected="2" Shared="75617508113728" Minshare="10737418240" Minslots="1" Maxhubs="240" Maxusers="18000" Status="Online" Reliability="97.9" Rating="0" Software="" Website="" Email="" ASN="Bahnhof AB" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="DjCosti - FRZ Ż`PRAHOVA´Ż" Address="frz.hopto.org:1209" Secure="" Description="Hub Prahova" Country="Romania" Encoding="COSTIDJ.CM@GMAIL.COM" Users="33" Operators="2" Bots="0" Clones="0" Infected="1" Shared="5330124314206" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="400" Status="Online" Reliability="89.88" Rating="139" Software="YnHub" Website="" Email="" ASN="Liberty Global B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[Asgard]Vamps Home" Address="vamps.asgards.org:4111" Secure="" Description="all you&apos;r dark dreams come true" Country="United Kingdom" Encoding="CP1252" Users="46" Operators="4" Bots="1" Clones="1" Infected="1" Shared="35474868781687" Minshare="1073741824" Minslots="0" Maxhubs="1000" Maxusers="200" Status="Online" Reliability="99.58" Rating="0" Software="FlexHub" Website="" Email="" ASN="Simply Transit Ltd" Network="Asgards" Failover="" Logo="" Icon="" />
		<Hub Name="QUEEN • HUB" Address="queen-hub.hostpl.eu" Secure="" Description="...::: Hosted by Hostpl.eu :::... - International Hub - Welcome to *** QUEEN HUB *** - http://www.hosting.hostpl.eu" Country="Poland" Encoding="CP1250" Users="39" Operators="0" Bots="3" Clones="0" Infected="0" Shared="80462708253942" Minshare="5368709120" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="98.09" Rating="0" Software="Verlihub" Website="" Email="" ASN="SERVERS-COM" Network="Host PL" Failover="" Logo="" Icon="" />
		<Hub Name="Baltezers" Address="baltezers.no-ip.info" Secure="" Description="kladoffka" Country="Latvia" Encoding="CP1251" Users="39" Operators="8" Bots="0" Clones="0" Infected="2" Shared="23409205111838" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="500" Status="Online" Reliability="94.16" Rating="0" Software="PtokaX" Website="" Email="" ASN="SIA Tet" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="HUB-ck.ua" Address="hub.dc.ck.ua:4111" Secure="" Description="" Country="Ukraine" Encoding="CP1251" Users="37" Operators="1" Bots="0" Clones="1" Infected="1" Shared="39127792132888" Minshare="21474836480" Minslots="0" Maxhubs="0" Maxusers="8000" Status="Online" Reliability="93.98" Rating="0" Software="PtokaX" Website="" Email="" ASN="ISP Fregat Ltd." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="--==[FTTBkhv.RU]==--" Address="dc.fttbkhv.ru" Secure="" Description="--==[FTTBkhv.RU]==--" Country="Russian Federation" Encoding="CP1251" Users="33" Operators="0" Bots="2" Clones="0" Infected="0" Shared="17361464949038" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="93.25" Rating="0" Software="Verlihub" Website="" Email="" ASN="Aruba S.p.A." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="AU.Bitscomputer.Net" Address="au.bitscomputer.net:3800" Secure="" Description="Australia" Country="Australia" Encoding="CP1252" Users="37" Operators="3" Bots="1" Clones="0" Infected="0" Shared="439185423810984" Minshare="107374182400" Minslots="1" Maxhubs="50" Maxusers="1000" Status="Online" Reliability="98.19" Rating="11" Software="FlexHub" Website="http://au.bitscomputer.net/" Email="" ASN="LeaseWeb Netherlands B.V." Network="" Failover="dchub://gelmes.sytes.net:6666" Logo="" Icon="" />
		<Hub Name="[Asgard]SyFy Dreams" Address="dreams.asgards.org:4111" Secure="" Description="NMDC and ADC users in one hub" Country="United Kingdom" Encoding="CP1252" Users="40" Operators="4" Bots="1" Clones="0" Infected="0" Shared="32529873539274" Minshare="21474836480" Minslots="1" Maxhubs="1000" Maxusers="200" Status="Online" Reliability="99.53" Rating="0" Software="FlexHub" Website="http://www.asgards.org/" Email="" ASN="Simply Transit Ltd" Network="Asgards" Failover="" Logo="" Icon="" />
		<Hub Name="Lanport" Address="dc.lanport.ru" Secure="" Description="DC++ hub ISP Lanport" Country="Russian Federation" Encoding="CP1251" Users="38" Operators="4" Bots="0" Clones="0" Infected="1" Shared="45252160730032" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="20000" Status="Online" Reliability="61.69" Rating="0" Software="PtokaX" Website="http://lanport.ru/" Email="dc@lanport.net" ASN="Lanport-S LLC" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Ecolomania-Romania." Address="ecolomania.ro" Secure="" Description="Ecolomania-Romania." Country="Romania" Encoding="CP1252" Users="37" Operators="4" Bots="0" Clones="0" Infected="3" Shared="12985508884526" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="50000" Status="Online" Reliability="70.29" Rating="6" Software="YnHub" Website="" Email="" ASN="RCS &amp; RDS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="STAR HUB SPB" Address="starshub.bceti.com" Secure="" Description="Internet hub of St. Petersburg" Country="Ukraine" Encoding="CP1251" Users="37" Operators="2" Bots="0" Clones="0" Infected="0" Shared="40112844177874" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="2000" Status="Online" Reliability="99.79" Rating="0" Software="PtokaX" Website="" Email="" ASN="TOV TRK Briz" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="«•» Original Hub of Romania ® «•»" Address="hub.fioriginal.ro" Secure="" Description="----------------=&gt; HIGH SPEED &lt;=-----=&gt; ROMANIA &lt;=-------=&gt; BUCURESTI &lt;=------=&gt; FREE SHARE &lt;=------=&gt; ORIGINAL DC HUB &lt;=-------------------------------" Country="Romania" Encoding="CP1252" Users="33" Operators="0" Bots="2" Clones="0" Infected="0" Shared="4854325471191" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="2000" Status="Online" Reliability="84.24" Rating="0" Software="Verlihub" Website="http://fioriginal.ro/" Email="" ASN="Nav Communications Srl" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Ex-BIG.Hub" Address="dc.dmvn.net:1441" Secure="" Description="Ex-BIG Corbina/Beeline Izmaylovo District Hub" Country="Estonia" Encoding="CP1251" Users="35" Operators="3" Bots="0" Clones="0" Infected="0" Shared="36832173935390" Minshare="0" Minslots="1" Maxhubs="0" Maxusers="10001" Status="Online" Reliability="99.59" Rating="0" Software="PtokaX" Website="http://dc.dmvn.net/" Email="" ASN="P.a.g.m. Ou" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="ÜndèrGrøund® Ñètwø®k Ðümp Hüß" Address="dumphub.udgnet.com:714" Secure="" Description="ÜndèrGrøund® Ñètwø®k a place for everyone" Country="Sweden" Encoding="CP1252" Users="36" Operators="1" Bots="1" Clones="1" Infected="0" Shared="24698576151691" Minshare="0" Minslots="1" Maxhubs="1000" Maxusers="1000" Status="Online" Reliability="98.3" Rating="0" Software="FlexHub" Website="http://udgnet.com/" Email="" ASN="Olofstroms Kabel-TV AB" Network="Underground Network" Failover="dchub://home.udgnet.com:7778" Logo="" Icon="" />
		<Hub Name="Franco Hub Public" Address="fhppublic.ddns.net:1209" Secure="" Description="[KVN] Hub Network Leviathan™ 2nd Generation v. 1.4[B3]" Country="Netherlands" Encoding="CP1252" Users="39" Operators="5" Bots="0" Clones="0" Infected="1" Shared="198043502284008" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="500" Status="Online" Reliability="95.95" Rating="5" Software="PtokaX" Website="" Email="" ASN="Shpv France SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="ValceaHub" Address="dc.valceahub.ro" Secure="" Description="ROMANIA BUCURESTI Rar Apps mpeg Punk Download avi Covers Pictures Comics Rap International Windows HipHop porn Trance Chat images Techno Mp3 Music Prison Break Movies Network TV shows divx Gossip Girl Audio books PS3 Sound clips Warez mpg Games swiss Grey" Country="Romania" Encoding="CP1252" Users="37" Operators="2" Bots="2" Clones="0" Infected="0" Shared="16668099328053" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="1024" Status="Online" Reliability="99.88" Rating="0" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="•««•][•SunVision•HUB•][•»»•" Address="sunvision.ba-lee.eu:1741" Secure="" Description="" Country="Hungary" Encoding="CP1252" Users="32" Operators="0" Bots="4" Clones="0" Infected="2" Shared="14745497854361" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="95.3" Rating="0" Software="Verlihub" Website="http://ba-lee.eu/" Email="" ASN="Contabo GmbH" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Kharkiv national university of radioelectronics" Address="goldnet.org.ua" Secure="" Description="Kharkiv national university of radioelectronics" Country="Ukraine" Encoding="CP1251" Users="34" Operators="0" Bots="0" Clones="1" Infected="2" Shared="30488829021177" Minshare="0" Minslots="1" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="79.77" Rating="0" Software="PtokaX" Website="" Email="admin@knure.info" ASN="Content Delivery Network Ltd" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[KVN]•Dutch Royale • DC++" Address="kvn.zapto.org:413" Secure="" Description="¨°º ¤-=[Kñigh†VisioÑ.::.Ñe†WorX]=-¤ •Dutch Royale • DC++- Cannabis Reggae - Movies - Music - Programs Leviathan™ 2nd Generation v. 1.4" Country="Netherlands" Encoding="CP1252" Users="37" Operators="8" Bots="0" Clones="0" Infected="1" Shared="106088350258138" Minshare="0" Minslots="1" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="94.34" Rating="31" Software="PtokaX" Website="" Email="dutchpowernet@hotmail.com" ASN="Vodafone Libertel B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Verlihub" Address="dcorsk.ru" Secure="" Description="" Country="Russian Federation" Encoding="CP1251" Users="33" Operators="0" Bots="4" Clones="1" Infected="0" Shared="31983224688405" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="79.79" Rating="0" Software="Verlihub" Website="" Email="" ASN="Joint Stock Company TransTeleCom" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="-=SperantzaHub=-" Address="sperantza.multi-mix.ro:2014" Secure="" Description="SperantzaHub - Programe - Mac - Linux - Windows - Images - Covers - Pictures - Games - DOWNLOAD - PSP - Rar - Iso - Apps - Crack - KeyGen - Filme - Episodes - 3D - XviD - DivX - DVD9 - HDTV -Sport - Movieclip - x264 - 1080p" Country="Romania" Encoding="CP1252" Users="36" Operators="0" Bots="42" Clones="0" Infected="1" Shared="12597422568731" Minshare="0" Minslots="0" Maxhubs="888" Maxusers="6000" Status="Online" Reliability="98.85" Rating="0" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="Multi Mix" Failover="" Logo="" Icon="" />
		<Hub Name="Tigarooo &amp; Komtelek" Address="tigarooo.sytes.net" Secure="" Description="Tigarooo" Country="Bulgaria" Encoding="CP1251" Users="30" Operators="2" Bots="0" Clones="0" Infected="1" Shared="23833505035052" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="95.71" Rating="0" Software="YnHub" Website="" Email="" ASN="Unics EOOD" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Game Of Thrones" Address="newsdownload.duckdns.org:1000" Secure="" Description="TVSeriesEpisodesGOTMarvelBigBangTheoryArrowGrey&apos;sAnatomy2BrokeTeenGirlsTheWalkingDeadTheFlashChicagoFirePDCriminalMindsZooHawaiiFiveOGrimmGothamReignBonesSupernaturalAliasAwkwardAmericanHorrorStory" Country="Lithuania" Encoding="CP1252" Users="33" Operators="0" Bots="1" Clones="0" Infected="1" Shared="14259028383646" Minshare="0" Minslots="0" Maxhubs="1000" Maxusers="1000" Status="Online" Reliability="97.79" Rating="0" Software="FlexHub" Website="" Email="" ASN="UAB Rakrejus" Network="" Failover="pazzomondohub.sytes.net" Logo="" Icon="" />
		<Hub Name="ITA •BrianzaLand Community•™ «««:::•€x†®em€-N€†•™:::»»»" Address="brianzaland.ex3menet.com:443" Secure="" Description="[8000+ USERS] FREE SEARCHES [RU,RO,IT,HUN,PL,SE]" Country="Italy" Encoding="CP1252" Users="29" Operators="2" Bots="0" Clones="0" Infected="0" Shared="4757014596176" Minshare="0" Minslots="1" Maxhubs="200" Maxusers="5000" Status="Online" Reliability="97.74" Rating="0" Software="PtokaX" Website="" Email="brianzaland@email.it" ASN="LeaseWeb Netherlands B.V." Network="Ex3me Network" Failover="" Logo="" Icon="" />
		<Hub Name="PROFI-HUB-LODZ" Address="profi-hub.odysejahub.com:1047" Secure="" Description="Music,Video,Films,Games,Programs" Country="Poland" Encoding="CP1250" Users="36" Operators="5" Bots="0" Clones="0" Infected="0" Shared="12278719669779" Minshare="0" Minslots="0" Maxhubs="300" Maxusers="200" Status="Online" Reliability="99.77" Rating="0" Software="Verlihub" Website="" Email="" ASN="LeaseWeb Netherlands B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="TrioLan" Address="triolan.hopto.org" Secure="" Description="" Country="Russian Federation" Encoding="CP1251" Users="33" Operators="4" Bots="6" Clones="0" Infected="0" Shared="56317508842003" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="20480" Status="Online" Reliability="97.99" Rating="0" Software="Verlihub" Website="" Email="" ASN="IP Ivanov Dmitry Alekseevich" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="The best Reggae Roots 2021. - Reggae power+The Brazil Network" Address="roots.servemp3.com:1411" Secure="" Description="" Country="Brazil" Encoding="CP1252" Users="32" Operators="5" Bots="0" Clones="0" Infected="0" Shared="131667981870743" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="0" Status="Online" Reliability="92.22" Rating="0" Software="PtokaX" Website="" Email="" ASN="IDEALNET FIBRA" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="† DivxIta-Horror __----__--___----&gt; 2010 †" Address="terminator-club.no-ip.info" Secure="" Description="Musica Video Ecc....." Country="Italy" Encoding="CP1252" Users="32" Operators="8" Bots="0" Clones="0" Infected="2" Shared="14712228103576" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="500" Status="Online" Reliability="97.68" Rating="16" Software="PtokaX" Website="" Email="" ASN="Telecom Italia" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="KMV-Aquila" Address="kmv-hub.tk:2411" Secure="" Description="Aquila Direct Connect Hub" Country="Russian Federation" Encoding="CP1251" Users="31" Operators="2" Bots="0" Clones="0" Infected="1" Shared="39358026922982" Minshare="0" Minslots="65535" Maxhubs="65535" Maxusers="5000" Status="Online" Reliability="94.47" Rating="0" Software="Aquila" Website="http://kmv-hub.tk/" Email="" ASN="PVimpelCom" Network="KMV" Failover="" Logo="" Icon="" />
		<Hub Name="[MTS]" Address="80.247.96.153" Secure="" Description="1" Country="Russian Federation" Encoding="CP1251" Users="35" Operators="0" Bots="2" Clones="0" Infected="1" Shared="41083677723003" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="96.51" Rating="0" Software="Verlihub" Website="" Email="" ASN="MTS PJSC" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="***ABTOBOK3AJl***" Address="web.aqproject.ru" Secure="" Description="No Description" Country="Russian Federation" Encoding="CP1251" Users="32" Operators="12" Bots="0" Clones="0" Infected="0" Shared="27672847401547" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="6000" Status="Online" Reliability="83.98" Rating="0" Software="Verlihub" Website="http://aqproject.ru/" Email="" ASN="PVimpelCom" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Mellon DC Hub" Address="dczone.ru" Secure="" Description="Щелковский DC++ Хаб" Country="Russian Federation" Encoding="CP1251" Users="30" Operators="2" Bots="0" Clones="0" Infected="2" Shared="49973383866736" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="10000" Status="Online" Reliability="70.69" Rating="0" Software="PtokaX" Website="http://dczone.ru/" Email="nicochaos@mail.ru" ASN="OOO Trivon Networks" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="©[•AUSTRIA-HUB•]" Address="austria.slak-pc.net:1510" Secure="" Description="[• Deutschland, Austria, Österreich, Sweden, Norwegen Slovenija,Bugarska,Bosna,Hrvatska,Srbija,Makedonija,Crna Gora, Ex-yu, Balkan,EU,EN,USA•]" Country="Austria" Encoding="CP1252" Users="29" Operators="1" Bots="3" Clones="0" Infected="2" Shared="11845249408343" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="300" Status="Online" Reliability="99.23" Rating="0" Software="Verlihub" Website="" Email="" ASN="LIWEST Kabelmedien GmbH" Network="Slak PC" Failover="" Logo="" Icon="" />
		<Hub Name="NorWiFi.com" Address="norwifi.com" Secure="" Description="" Country="Russian Federation" Encoding="CP1251" Users="32" Operators="1" Bots="0" Clones="0" Infected="0" Shared="57917554184489" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="2500" Status="Online" Reliability="96.65" Rating="0" Software="PtokaX" Website="" Email="" ASN="Norilsk-Telecom JSC" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="--== B.I.Z.M.O ==--" Address="bizmo.sytes.net:8888" Secure="" Description="Welcome to Bizmo - the first global Lifehack community!" Country="Hungary" Encoding="CP1252" Users="30" Operators="3" Bots="0" Clones="0" Infected="2" Shared="15049455271651" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="500" Status="Online" Reliability="99.95" Rating="0" Software="Verlihub" Website="" Email="" ASN="Hetzner Online GmbH" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="..::Towarzyski::.." Address="towarzyski.hostpl.eu:1234" Secure="" Description="Hub dla wszystkich:)" Country="Poland" Encoding="CP1250" Users="29" Operators="3" Bots="3" Clones="0" Infected="1" Shared="119760151274239" Minshare="1073741824" Minslots="0" Maxhubs="0" Maxusers="200" Status="Online" Reliability="99.81" Rating="0" Software="Verlihub" Website="" Email="" ASN="SERVERS-COM" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Atco &amp; Violet Passion" Address="timi.hopto.org" Secure="" Description="Atco &amp; Violet Passion is Back" Country="Spain" Encoding="TIMI@ATCO.RO" Users="33" Operators="4" Bots="0" Clones="0" Infected="1" Shared="24247678120232" Minshare="1073741824" Minslots="0" Maxhubs="0" Maxusers="2980" Status="Online" Reliability="99.38" Rating="0" Software="YnHub" Website="" Email="" ASN="Procono S.A." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="UK-Northeast" Address="northeast.no-ip.info:1209" Secure="" Description="MOVIES•MUSIC•NEW CHART &amp; DJ ALBUMS•TV SHOWS•GAMES•" Country="United Kingdom" Encoding="CP1252" Users="31" Operators="17" Bots="0" Clones="0" Infected="1" Shared="29475446422177" Minshare="6442450944" Minslots="1" Maxhubs="40" Maxusers="250" Status="Online" Reliability="98.05" Rating="1" Software="PtokaX" Website="" Email="" ASN="Virgin Media Limited" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="• A L W A Y S • 24/7 •" Address="always24.dchub.pl:1411" Secure="" Description="hosted by DCHUB.PL (uTe)" Country="Poland" Encoding="CP1252" Users="30" Operators="1" Bots="0" Clones="0" Infected="0" Shared="15349435305344" Minshare="5368709120" Minslots="0" Maxhubs="255" Maxusers="6000" Status="Online" Reliability="98.88" Rating="0" Software="HeXHub" Website="" Email="" ASN="H88 S.A." Network="" Failover="" Logo="" Icon="https://1drv.ms/u/s!AjfhqxYcgpVfnH7f9NvrmO4jP1ad?e=SLquKv" />
		<Hub Name="~~&gt;Природа&lt;~~" Address="ilya.pp.ua" Secure="" Description="GNU/Linux openSUSE KDE Харьков Природный Круглосуточный" Country="Ukraine" Encoding="CP1251" Users="30" Operators="2" Bots="0" Clones="0" Infected="0" Shared="34086784697466" Minshare="0" Minslots="5" Maxhubs="0" Maxusers="32767" Status="Online" Reliability="72.45" Rating="0" Software="PtokaX" Website="https://ilya.pp.ua/" Email="ilya@ilya.pp.ua" ASN="Ltd. Cypher" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="ObseSSion-Hub" Address="obsession.zapto.org" Secure="" Description="" Country="Romania" Encoding="CP1252" Users="30" Operators="1" Bots="4" Clones="0" Infected="3" Shared="11002964788119" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="99.39" Rating="2498" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="FRINGE" Address="fringe.choszting.hu:1597" Secure="" Description="[HUN][ENG][EU]--Fringe--Rejtély--Sci-Fi--Paranormal--Free--HUB" Country="Hungary" Encoding="CP1250" Users="31" Operators="0" Bots="3" Clones="0" Infected="2" Shared="13402663792031" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="99.7" Rating="0" Software="Verlihub" Website="" Email="" ASN="SzerverPlex.hu KFT." Network="" Failover="" Logo="" Icon="http://choszting.hu/fringe/favicon.ico" />
		<Hub Name="&lt;/Белый камень&gt;" Address="masterdan.donet.ru" Secure="" Description="RUUARSBY" Country="Russian Federation" Encoding="CP1251" Users="33" Operators="1" Bots="0" Clones="0" Infected="2" Shared="53916731569849" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="500" Status="Online" Reliability="95.8" Rating="0" Software="PtokaX" Website="http://masterdan.donet.ru/" Email="masterdan@donet.ru" ASN="MTS PJSC" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="iCiBiCi" Address="dc.90s.fr:4111" Secure="" Description="Join Join Join" Country="France" Encoding="CP1252" Users="31" Operators="1" Bots="3" Clones="0" Infected="2" Shared="25088592899334" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="94.82" Rating="0" Software="Verlihub" Website="" Email="" ASN="Online S.a.s." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="zHub" Address="zhub.overflow.biz" Secure="" Description="" Country="Brazil" Encoding="CP1252" Users="30" Operators="1" Bots="0" Clones="1" Infected="1" Shared="69965823175166" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="500" Status="Online" Reliability="93.22" Rating="0" Software="PtokaX" Website="" Email="" ASN="TELEFONICA BRASIL S.A" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[Asgard]Orbital One" Address="redirect.dreams.asgards.org" Secure="" Description="NMDC and ADC users in one hub" Country="United Kingdom" Encoding="CP1252" Users="31" Operators="2" Bots="1" Clones="0" Infected="0" Shared="30516817617988" Minshare="1073741824" Minslots="0" Maxhubs="1000" Maxusers="1000" Status="Online" Reliability="99.55" Rating="0" Software="FlexHub" Website="" Email="" ASN="Simply Transit Ltd" Network="Asgards" Failover="" Logo="" Icon="" />
		<Hub Name="Ruda Slaska" Address="ruda-slaska.hostpl.eu:2000" Secure="" Description="" Country="Poland" Encoding="CP1252" Users="30" Operators="3" Bots="3" Clones="0" Infected="1" Shared="86337735997483" Minshare="21474836480" Minslots="0" Maxhubs="0" Maxusers="100" Status="Online" Reliability="95.91" Rating="0" Software="Verlihub" Website="" Email="" ASN="SERVERS-COM" Network="Host PL" Failover="" Logo="" Icon="" />
		<Hub Name="Original Country Hub®" Address="romania.fioriginal.ro:412" Secure="" Description="...:::][:: N O L I M I T S - F R E E S H A R E - 0 S E C O N D S S E A R C H T I M E ::][:::..." Country="Romania" Encoding="CP1252" Users="26" Operators="0" Bots="2" Clones="0" Infected="0" Shared="3196117312271" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="10000" Status="Online" Reliability="81.63" Rating="0" Software="Verlihub" Website="http://fioriginal.ro/" Email="" ASN="Nav Communications Srl" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="DNIPRO.SYTES.NET" Address="dnipro.sytes.net" Secure="nmdcs://dnipro.sytes.net:411" Description="Ukraine 24/7 | Alt.ports:420,404,444,4111,4411,4441 | Use secure connection: nmdcs://dnipro.sytes.net:411" Country="Ukraine" Encoding="CP1251" Users="30" Operators="0" Bots="4" Clones="1" Infected="0" Shared="19345604117608" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="2500" Status="Online" Reliability="99.5" Rating="0" Software="Verlihub" Website="" Email="" ASN="Private entrepreneur Anastasiya Khizha" Network="" Failover="" Logo="http://ix-ua.net/Incoming/DneiPro)/2019.06.20.jpg" Icon="http://ix-ua.net/images/freebsd.png" />
		<Hub Name="•(¯`·._.~·°Tony&apos;s Music Room°·~._.·´¯)•" Address="tonys-musicroom.no-ip.info" Secure="" Description="(¯`·._.~·°Tony&apos;s Music Room°·~._.·´¯)" Country="United Kingdom" Encoding="CP1252" Users="27" Operators="14" Bots="0" Clones="0" Infected="0" Shared="44279483670018" Minshare="5368709120" Minslots="1" Maxhubs="100" Maxusers="300" Status="Online" Reliability="84.28" Rating="0" Software="PtokaX" Website="" Email="" ASN="British Telecommunications PLC" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="&quot;Октябрьский&quot;" Address="dchub.okdc.ru" Secure="" Description="Игровой - информационный хаб" Country="Russian Federation" Encoding="CP1251" Users="27" Operators="6" Bots="0" Clones="0" Infected="0" Shared="36808863034349" Minshare="3145728000" Minslots="1" Maxhubs="17" Maxusers="6000" Status="Online" Reliability="92.67" Rating="-1" Software="Verlihub" Website="" Email="" ASN="PVimpelCom" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[_Rebel-World_] - [ International HUB ] - [ #StaySafe ] - [ Share &amp; Enjoy !] - - - [ dchub://world.rebelnetwork.ro:888 ]..............................................." Address="world.rebelnetwork.ro:888" Secure="" Description="International HUB" Country="Romania" Encoding="CP1252" Users="29" Operators="0" Bots="2" Clones="0" Infected="2" Shared="15516668835466" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="99.66" Rating="0" Software="Verlihub" Website="" Email="" ASN="UAB Rakrejus" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Its All About Music" Address="meermuziek.no-ip.org:4111" Secure="" Description="NMDC and ADC users in one hub" Country="Netherlands" Encoding="CP1252" Users="31" Operators="1" Bots="1" Clones="0" Infected="1" Shared="28142123834221" Minshare="0" Minslots="2" Maxhubs="1000" Maxusers="501" Status="Online" Reliability="92.9" Rating="0" Software="FlexHub" Website="" Email="" ASN="Vodafone Libertel B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="--== IMPERIUM ==--" Address="imperium1.pl:1234" Secure="" Description="..........:::::::::: W E L C O M E TO P O L I S H H U B I M P E R I U M::::::::::.........." Country="Poland" Encoding="CP1252" Users="28" Operators="5" Bots="0" Clones="0" Infected="1" Shared="16966354823478" Minshare="1073741824" Minslots="1" Maxhubs="100" Maxusers="3000" Status="Online" Reliability="95.5" Rating="0" Software="Verlihub" Website="http://imperium1.pl/" Email="" ASN="LeaseWeb Netherlands B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="myDC&apos;s HuB - Have A Good Day" Address="hub.mydc.ru" Secure="" Description="" Country="Russian Federation" Encoding="CP1251" Users="29" Operators="2" Bots="0" Clones="2" Infected="0" Shared="37175581517162" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="0" Status="Online" Reliability="99.93" Rating="0" Software="PtokaX" Website="" Email="" ASN="MnogoByte LLC" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="UDP ®Networks" Address="dc.udp.ro" Secure="" Description="UDP ®Networks Hub, providing p2p file sharing capability." Country="Romania" Encoding="CP1250" Users="27" Operators="4" Bots="0" Clones="0" Infected="2" Shared="14160417556573" Minshare="1073741824" Minslots="3" Maxhubs="100" Maxusers="2110" Status="Online" Reliability="99.71" Rating="0" Software="Verlihub" Website="" Email="" ASN="Bms It Group Srl" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="° ßLÅÇKØÚ† ° -=VØLK§~Fµ§‡ØÑ~Ñè†=-" Address="blackout.volksfusion.net:1090" Secure="" Description="BLACKOUT" Country="Italy" Encoding="CP1252" Users="26" Operators="2" Bots="0" Clones="1" Infected="2" Shared="18338646459762" Minshare="0" Minslots="1" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="99.98" Rating="0" Software="PtokaX" Website="" Email="" ASN="LeaseWeb Netherlands B.V." Network="Volks Fusion" Failover="" Logo="" Icon="" />
		<Hub Name="ll---===[Word2-hub]===---ll" Address="word2-hub.bucihost.net:2121" Secure="" Description="" Country="Hungary" Encoding="CP1252" Users="25" Operators="5" Bots="0" Clones="0" Infected="1" Shared="12429470298947" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="500" Status="Online" Reliability="99.96" Rating="0" Software="Verlihub" Website="" Email="" ASN="Hetzner Online GmbH" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[-SmurfNetwork-][-Smurfland-]-[Uppsala-]" Address="snw1.zapto.org:400" Secure="" Description="[-SmurfNetwork-][-Smurfland-]-[Uppsala-]" Country="Sweden" Encoding="CP1252" Users="25" Operators="8" Bots="0" Clones="0" Infected="1" Shared="3369724722587" Minshare="0" Minslots="2" Maxhubs="0" Maxusers="50000" Status="Online" Reliability="99.07" Rating="0" Software="YnHub" Website="" Email="" ASN="Bredband2 AB" Network="SmurfNetwork" Failover="" Logo="" Icon="" />
		<Hub Name="MDF-Twilight-Zone" Address="twilight.webfunzone.info:1991" Secure="" Description="No Description" Country="Italy" Encoding="CP1252" Users="30" Operators="0" Bots="7" Clones="0" Infected="1" Shared="62246652017396" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="700" Status="Online" Reliability="98.37" Rating="190" Software="Verlihub" Website="" Email="" ASN="Aruba S.p.A." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Hub" Address="dc.yonl.ru" Secure="" Description="" Country="Russian Federation" Encoding="CP1252" Users="24" Operators="0" Bots="2" Clones="0" Infected="1" Shared="38378978000753" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="91.86" Rating="0" Software="Verlihub" Website="http://dc.yonl.ru/" Email="" ASN="You Online LLC" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="DcHost support hub" Address="dchost.eu:99" Secure="" Description="" Country="Poland" Encoding="CP1252" Users="24" Operators="3" Bots="0" Clones="0" Infected="1" Shared="18469868487820" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="1000" Status="Online" Reliability="98.04" Rating="0" Software="Verlihub" Website="" Email="" ASN="LeaseWeb Netherlands B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[-SmurfNetwork-][-Smurfland-]-[Småland-]" Address="snw3.webredirect.org:5656" Secure="" Description="[-SmurfNetwork-][-Smurfland-]-[Småland-]" Country="Sweden" Encoding="CP1252" Users="25" Operators="10" Bots="0" Clones="0" Infected="1" Shared="3026273951580" Minshare="0" Minslots="1" Maxhubs="0" Maxusers="3000" Status="Online" Reliability="99.51" Rating="0" Software="YnHub" Website="" Email="" ASN="Bredband2 AB" Network="SmurfNetwork" Failover="" Logo="" Icon="" />
		<Hub Name="Stargate Command" Address="sgc.sna-world.org:4111" Secure="" Description="Milky Way Galaxy.dxb" Country="Romania" Encoding="CP1250" Users="28" Operators="1" Bots="0" Clones="1" Infected="2" Shared="11504494745192" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="10000" Status="Online" Reliability="100" Rating="0" Software="PtokaX" Website="" Email="" ASN="Informacines sistemos ir technologijos, UAB" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="hub of getfr" Address="getfr.org" Secure="" Description="No Description" Country="Russian Federation" Encoding="CP1251" Users="24" Operators="3" Bots="0" Clones="1" Infected="0" Shared="19601796690939" Minshare="1048576" Minslots="3" Maxhubs="100" Maxusers="6000" Status="Online" Reliability="97.98" Rating="0" Software="Verlihub" Website="http://getfr.org/" Email="" ASN="PVimpelCom" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Romania Crestina" Address="romaniacrestina.ro:4012" Secure="" Description="Hub Crestin Ortodox - NUMAI PT. CRESTINI !!!" Country="Romania" Encoding="CP1252" Users="20" Operators="2" Bots="3" Clones="0" Infected="0" Shared="3266083421148" Minshare="0" Minslots="1" Maxhubs="100" Maxusers="2000" Status="Online" Reliability="66.58" Rating="0" Software="Verlihub" Website="" Email="" ASN="Net Gate Comunicatii Srl" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="~• Hiroshima • Mon Amour •~ -=VØLK§~Fµ§‡ØÑ~Ñè†=-" Address="crocedelizia.volksfusion.net:9999" Secure="" Description="-=VOLKSFUSION.NET=- cinema•noir•classics•neorealismo•film•nouvelle vague•rock,jazz,blues,folk music" Country="Italy" Encoding="CP1252" Users="22" Operators="2" Bots="0" Clones="0" Infected="1" Shared="19445763846747" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="99.99" Rating="0" Software="PtokaX" Website="" Email="" ASN="LeaseWeb Netherlands B.V." Network="Volks Fusion" Failover="" Logo="" Icon="" />
		<Hub Name="2MAV Hub" Address="2mav.ro" Secure="" Description="FUN&amp;Trivia" Country="Romania" Encoding="CP1252" Users="25" Operators="0" Bots="4" Clones="0" Infected="2" Shared="11789095383118" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="99.77" Rating="0" Software="Verlihub" Website="" Email="" ASN="Telekom Romania Communication S.A" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="CyberLAN" Address="77.68.14.54:1209" Secure="" Description="Anime Hentai Movies TV Music Manga XXX Games. Everything." Country="United Kingdom" Encoding="CP1252" Users="28" Operators="1" Bots="0" Clones="0" Infected="1" Shared="14844436514090" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="500" Status="Online" Reliability="100" Rating="0" Software="PtokaX" Website="" Email="" ASN="1&amp;1 Ionos Se" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Sc0rpions Lair" Address="sc0rpion.ddns.net:1411" Secure="" Description="Welcome to Sc0rpions Lair, To be added as VIP register with the [SL] prefix" Country="United States" Encoding="CP1252" Users="25" Operators="1" Bots="1" Clones="1" Infected="1" Shared="15862459304142" Minshare="0" Minslots="0" Maxhubs="1000" Maxusers="1000" Status="Online" Reliability="99.85" Rating="0" Software="FlexHub" Website="" Email="dave@dutyhosts.net" ASN="Netrouting" Network="" Failover="sharecentral.ddns.net" Logo="" Icon="" />
		<Hub Name="-=GoodLookingMusic=- - Today&apos;s birthday(s): -=Rasta_Boef=-; RastaBoef" Address="77.167.85.143" Secure="" Description="" Country="Netherlands" Encoding="CP1252" Users="22" Operators="9" Bots="0" Clones="0" Infected="0" Shared="143616773757114" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="0" Status="Online" Reliability="95.77" Rating="0" Software="PtokaX" Website="" Email="" ASN="KPN B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[-SmurfNetwork-][-Smurfland-]-[Karlstad-]" Address="snw2.webredirect.org:1337" Secure="" Description="[-SmurfNetwork-][-Smurfland-]-[Karlstad-]" Country="Sweden" Encoding="CP1252" Users="24" Operators="7" Bots="0" Clones="0" Infected="1" Shared="3506029188248" Minshare="10737418240" Minslots="3" Maxhubs="0" Maxusers="30000" Status="Online" Reliability="99.22" Rating="0" Software="YnHub" Website="" Email="" ASN="Bredband2 AB" Network="SmurfNetwork" Failover="" Logo="" Icon="" />
		<Hub Name="JUNGLiST" Address="drumnbass.lv" Secure="" Description="[DNB] [Drum N Bass] [Drum &amp; Bass] [Jungle] [Breakbeatz] [DRUMNBASS.LV]" Country="Latvia" Encoding="CP1252" Users="21" Operators="7" Bots="0" Clones="0" Infected="0" Shared="86763012345199" Minshare="53687091200" Minslots="2" Maxhubs="0" Maxusers="100" Status="Online" Reliability="98.1" Rating="1" Software="PtokaX" Website="http://www.drumnbass.lv/" Email="" ASN="Hetzner Online GmbH" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Its All About Games" Address="meergames.no-ip.org:412" Secure="" Description="NMDC and ADC users in one hub" Country="Netherlands" Encoding="CP1252" Users="23" Operators="0" Bots="1" Clones="0" Infected="1" Shared="20140578819910" Minshare="0" Minslots="2" Maxhubs="1000" Maxusers="501" Status="Online" Reliability="94.45" Rating="0" Software="FlexHub" Website="" Email="" ASN="Vodafone Libertel B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="BlazingPhoenix.org DC++" Address="blazingphoenix.org" Secure="" Description="True Blue Aussie Server! Mid North Coast Game Servers" Country="Australia" Encoding="CP1252" Users="21" Operators="1" Bots="0" Clones="0" Infected="2" Shared="69882366276871" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="65" Rating="1" Software="YnHub" Website="http://blazingphoenix.org/" Email="" ASN="Superloop" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Cosmos" Address="dc.80s.lt" Secure="" Description="Everything here is somehow strangely related..." Country="Lithuania" Encoding="CP1252" Users="22" Operators="1" Bots="3" Clones="0" Infected="2" Shared="17161085034082" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="97.85" Rating="0" Software="Verlihub" Website="http://80s.lt/" Email="" ASN="Online S.a.s." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="CNC_DanHub" Address="212.116.114.17" Secure="" Description="CNC_Date" Country="Russian Federation" Encoding="CP1251" Users="25" Operators="2" Bots="0" Clones="0" Infected="0" Shared="55888256901572" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="500" Status="Online" Reliability="95.91" Rating="0" Software="PtokaX" Website="" Email="" ASN="Prometey LLC" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="dc.nowecom.ru" Address="dc.nowecom.ru" Secure="" Description="" Country="Russian Federation" Encoding="CP1251" Users="26" Operators="2" Bots="0" Clones="0" Infected="1" Shared="27079910803466" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="500" Status="Online" Reliability="99.11" Rating="0" Software="PtokaX" Website="" Email="" ASN="OOO Severo-Zapadnye telekommunikacii" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Adam-LV-TEST" Address="adamlv.ddns.net:405" Secure="" Description="Leviathan v4.0 - FR" Country="France" Encoding="CP1252" Users="21" Operators="9" Bots="0" Clones="0" Infected="0" Shared="159097334714699" Minshare="10737418240" Minslots="0" Maxhubs="0" Maxusers="250" Status="Online" Reliability="96.86" Rating="1" Software="PtokaX" Website="" Email="" ASN="SFR SA" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[KVN]•Leviathan_test_area•" Address="knightvision.servebeer.com" Secure="" Description="Leviathan™ 2nd Generation v. 1.4.1" Country="Finland" Encoding="CP1252" Users="23" Operators="5" Bots="0" Clones="0" Infected="0" Shared="11090052168016" Minshare="0" Minslots="1" Maxhubs="0" Maxusers="20000" Status="Online" Reliability="67.59" Rating="0" Software="PtokaX" Website="" Email="" ASN="Elisa Oyj" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="The Internet World DC++ Hub" Address="theinternetworld.no-ip.info" Secure="" Description="Powered By The Internet World - http://www.theinternetworld.org" Country="Greece" Encoding="CP1253" Users="22" Operators="2" Bots="1" Clones="0" Infected="0" Shared="11699836098066" Minshare="0" Minslots="0" Maxhubs="1000" Maxusers="1000" Status="Online" Reliability="88.56" Rating="0" Software="FlexHub" Website="http://www.theinternetworld.org/" Email="admin@theinternetworld.org" ASN="OTEnet S.A." Network="The Internet World" Failover="" Logo="" Icon="" />
		<Hub Name="Sensatione®" Address="sensatione.bucihost.net:2009" Secure="" Description="" Country="Romania" Encoding="CP1252" Users="24" Operators="5" Bots="0" Clones="0" Infected="1" Shared="12521642756189" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="500" Status="Online" Reliability="75.41" Rating="0" Software="Verlihub" Website="" Email="" ASN="Hetzner Online GmbH" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="sublevels.net hub resurrection" Address="paladin.sublevels.net" Secure="nmdcs://paladin.sublevels.net:411" Description="hub with experimental services" Country="United States" Encoding="CP1252" Users="21" Operators="0" Bots="2" Clones="1" Infected="1" Shared="14872928819000" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="97.38" Rating="0" Software="Verlihub" Website="" Email="" ASN="DIGITALOCEAN-ASN" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="DC.TERICOM.SU" Address="dc.tericom.su" Secure="" Description="No Description" Country="Soviet Union" Encoding="CP1251" Users="21" Operators="2" Bots="0" Clones="0" Infected="1" Shared="11209761638148" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="6000" Status="Online" Reliability="99.85" Rating="0" Software="Verlihub" Website="" Email="" ASN="Tericom LLC" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[DK]Christiania" Address="christiania.dyndns.dk" Secure="" Description="NMDC and ADC users in one hub" Country="Denmark" Encoding="CP1252" Users="22" Operators="2" Bots="1" Clones="0" Infected="1" Shared="10175935955917" Minshare="0" Minslots="1" Maxhubs="1000" Maxusers="1000" Status="Online" Reliability="66.01" Rating="0" Software="FlexHub" Website="" Email="christianiahub@gmail.com" ASN="Tele Danmark" Network="" Failover="dchub://thehomeofgarfield.no-ip.org:551" Logo="" Icon="" />
		<Hub Name="The Internet World DC++ Hub #3" Address="theinternetworld.no-ip.info:413" Secure="" Description="Powered By The Internet World - http://www.theinternetworld.org" Country="Greece" Encoding="CP1252" Users="19" Operators="2" Bots="1" Clones="0" Infected="0" Shared="6328952266436" Minshare="0" Minslots="0" Maxhubs="1000" Maxusers="1000" Status="Online" Reliability="88.51" Rating="0" Software="FlexHub" Website="http://www.theinternetworld.org/" Email="admin@theinternetworld.org" ASN="OTEnet S.A." Network="The Internet World" Failover="" Logo="" Icon="" />
		<Hub Name="Metalfans" Address="metalfans.klfree.net" Secure="" Description="Hub pro Metalovou muziku!!!! METAL FOREVER" Country="Czech Republic" Encoding="CP1252" Users="22" Operators="4" Bots="0" Clones="0" Infected="1" Shared="7787054413961" Minshare="0" Minslots="0" Maxhubs="40" Maxusers="6000" Status="Online" Reliability="99.14" Rating="0" Software="Verlihub" Website="http://metalfans.klfree.net/" Email="" ASN="FreeTel, s.r.o." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="©[•DEUTSCH-HUB•]" Address="de.slak-pc.net:6009" Secure="" Description="[• England,Deutschland, Austria, Österreich, Sweden, Norwegen Slovenija,Bugarska,Bosna,Hrvatska,Srbija,Makedonija,Crna Gora, Ex-yu, Balkan,EU,EN,USA•]" Country="Germany" Encoding="CP1250" Users="21" Operators="1" Bots="3" Clones="0" Infected="1" Shared="4215154882089" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="200" Status="Online" Reliability="96.61" Rating="0" Software="Verlihub" Website="http://slak-pc.net/" Email="" ASN="LIWEST Kabelmedien GmbH" Network="Slak PC" Failover="" Logo="" Icon="" />
		<Hub Name="[-Arvika-][-NaqNet-]" Address="arvikahubben.freeddns.org:66" Secure="" Description="[-Arvika-][-NaqNet-]" Country="Sweden" Encoding="CP1252" Users="20" Operators="11" Bots="0" Clones="0" Infected="1" Shared="3141389340588" Minshare="0" Minslots="2" Maxhubs="0" Maxusers="3000" Status="Online" Reliability="98.47" Rating="0" Software="YnHub" Website="" Email="" ASN="Bredband2 AB" Network="NaqNet" Failover="" Logo="" Icon="" />
		<Hub Name="[-SmurfNetwork-][-Smurfland-]-[HighShare-]" Address="snw-highshare.hopto.org:999" Secure="" Description="-SmurfNetwork-][-Smurfland-]-[HighShare-]" Country="Sweden" Encoding="CP1252" Users="22" Operators="9" Bots="0" Clones="0" Infected="1" Shared="8366041676215" Minshare="107374182400" Minslots="2" Maxhubs="0" Maxusers="30000" Status="Online" Reliability="98.23" Rating="0" Software="YnHub" Website="" Email="" ASN="Bredband2 AB" Network="SmurfNetwork" Failover="" Logo="" Icon="" />
		<Hub Name="FRANCE &amp; PARTAGE 2" Address="les-fanfarons.ddns.net" Secure="" Description="Leviathan v4.0 - FR" Country="France" Encoding="CP1252" Users="19" Operators="8" Bots="0" Clones="0" Infected="0" Shared="12651289739990" Minshare="1073741824" Minslots="0" Maxhubs="0" Maxusers="250" Status="Online" Reliability="84.33" Rating="0" Software="PtokaX" Website="" Email="" ASN="SFR SA" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Hip-Hop lair" Address="dreamland.no-ip.info:21" Secure="" Description="" Country="United States" Encoding="CP1252" Users="20" Operators="1" Bots="0" Clones="0" Infected="0" Shared="10880371340568" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="250" Status="Online" Reliability="89.9" Rating="0" Software="PtokaX" Website="" Email="" ASN="PERFORMIVE" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Wolfsburg-hub" Address="159.69.127.169:1975" Secure="" Description="Farkasok szövetsége!" Country="Germany" Encoding="CP1252" Users="21" Operators="3" Bots="0" Clones="0" Infected="1" Shared="13137695755918" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="300" Status="Online" Reliability="100" Rating="0" Software="Verlihub" Website="" Email="" ASN="Hetzner Online GmbH" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="The Competition! Fuck You and the Horse you rode in on Cowboy!" Address="thecompetition.no-ip.info:1511" Secure="" Description="YnHub is the cutest ever!" Country="Canada" Encoding="CP1252" Users="19" Operators="6" Bots="0" Clones="0" Infected="0" Shared="68763819077311" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="3000" Status="Online" Reliability="79.5" Rating="0" Software="YnHub" Website="" Email="" ASN="ATT-INTERNET4" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="HSB Bolina Lost Souls hubb" Address="hsblostsouls.no-ip.com:8643" Secure="" Description="2021-04-20 12:36:55 Äkta HSB Bolina/Telia stadsnät/Ownit LAN/MKB via B²/Brf Ellstorp via B² hubb. Hastigheter upp till 11.25 MB/s." Country="Sweden" Encoding="CP1252" Users="18" Operators="2" Bots="0" Clones="0" Infected="2" Shared="13382718400492" Minshare="10737418240" Minslots="3" Maxhubs="240" Maxusers="500" Status="Online" Reliability="90.7" Rating="0" Software="" Website="" Email="" ASN="Bahnhof AB" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="FLAC - Frog&apos;s Lossless Audiophile Community" Address="flac.dchost.eu:7777" Secure="" Description="Lossless Music (flac ape shn wv)" Country="Soviet Union" Encoding="CP1252" Users="17" Operators="1" Bots="2" Clones="0" Infected="0" Shared="24262061597157" Minshare="1073741824" Minslots="1" Maxhubs="30" Maxusers="500" Status="Online" Reliability="99.25" Rating="0" Software="Verlihub" Website="" Email="" ASN="LeaseWeb Netherlands B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Kolonija" Address="dc.marsland.eu" Secure="" Description="Lengvesne atmosfera.." Country="Lithuania" Encoding="CP1252" Users="19" Operators="1" Bots="3" Clones="0" Infected="2" Shared="11437365398302" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="98.38" Rating="0" Software="Verlihub" Website="" Email="" ASN="UAB ESNET" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[-Stockholm][-NaqNet-]" Address="naqnet.hopto.org:1411" Secure="" Description="[-Stockholm][-NaqNet-]" Country="Sweden" Encoding="CP1252" Users="19" Operators="8" Bots="0" Clones="0" Infected="0" Shared="2613769925313" Minshare="0" Minslots="1" Maxhubs="0" Maxusers="10000" Status="Online" Reliability="97.57" Rating="0" Software="YnHub" Website="" Email="" ASN="Bredband2 AB" Network="NaqNet" Failover="" Logo="" Icon="" />
		<Hub Name="[-Andos™-][-Halmstad-]" Address="andos.hopto.org:6969" Secure="" Description="-Andos™-][-Halmstad-]" Country="Sweden" Encoding="CP1252" Users="19" Operators="9" Bots="0" Clones="0" Infected="1" Shared="9236721898560" Minshare="0" Minslots="1" Maxhubs="0" Maxusers="30000" Status="Online" Reliability="96.37" Rating="0" Software="YnHub" Website="" Email="" ASN="Bredband2 AB" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="FRANCE &amp; PARTAGE 1" Address="chez-loloo.ddns.net:1411" Secure="" Description="Leviathan v4.0 - FR" Country="France" Encoding="CP1252" Users="17" Operators="8" Bots="0" Clones="0" Infected="0" Shared="14923376874286" Minshare="1073741824" Minslots="0" Maxhubs="0" Maxusers="250" Status="Online" Reliability="97.57" Rating="0" Software="PtokaX" Website="" Email="" ASN="SFR SA" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="The Internet World DC++ Hub #2" Address="theinternetworld.no-ip.info:412" Secure="" Description="Powered By The Internet World - http://www.theinternetworld.org" Country="Greece" Encoding="CP1252" Users="16" Operators="2" Bots="1" Clones="0" Infected="0" Shared="2215647908646" Minshare="0" Minslots="0" Maxhubs="1000" Maxusers="1000" Status="Online" Reliability="89" Rating="0" Software="FlexHub" Website="http://www.theinternetworld.org/" Email="admin@theinternetworld.org" ASN="OTEnet S.A." Network="The Internet World" Failover="" Logo="" Icon="" />
		<Hub Name="Hosting Hostpl.eu" Address="hub.hostpl.eu:3000" Secure="" Description="...::: Hosted by Hostpl.eu :::..." Country="Poland" Encoding="CP1252" Users="17" Operators="3" Bots="3" Clones="0" Infected="1" Shared="10466006552150" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="92.71" Rating="0" Software="Verlihub" Website="http://www.hosting.hostpl.eu/" Email="admin@hostpl.eu" ASN="SERVERS-COM" Network="Host PL" Failover="" Logo="" Icon="" />
		<Hub Name="AllWisdom" Address="allwisdom.org" Secure="" Description="http://AllWisdom.org" Country="Latvia" Encoding="CP1252" Users="19" Operators="0" Bots="2" Clones="0" Infected="2" Shared="12762152803915" Minshare="0" Minslots="0" Maxhubs="65535" Maxusers="1000" Status="Online" Reliability="97.89" Rating="0" Software="Verlihub" Website="http://allwisdom.org/" Email="" ASN="RN Data SIA" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Pro-Jazz Club" Address="dc.pro-jazz.com" Secure="" Description="Хаб сайта http://pro-jazz.com" Country="Russian Federation" Encoding="CP1251" Users="17" Operators="3" Bots="0" Clones="0" Infected="1" Shared="50605108645319" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="10000" Status="Online" Reliability="99.67" Rating="0" Software="PtokaX" Website="" Email="support@pro-jazz.com" ASN="Zomro B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[-Svenska Filmhubarna™-]" Address="sf1.hopto.org:444" Secure="" Description="[-Svenska Filmhubarna™-]" Country="Sweden" Encoding="CP1252" Users="18" Operators="9" Bots="0" Clones="0" Infected="1" Shared="5120847418068" Minshare="53687091200" Minslots="1" Maxhubs="0" Maxusers="30000" Status="Online" Reliability="97.56" Rating="0" Software="YnHub" Website="" Email="" ASN="Bredband2 AB" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="-=PtokaX Dev Hub=- - This is Linux land. In silent nights you can hear Windows machines rebooting..." Address="pepek.czdc.org:2002" Secure="" Description="" Country="Czech Republic" Encoding="CP1252" Users="18" Operators="2" Bots="0" Clones="0" Infected="0" Shared="8116372662129" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="0" Status="Online" Reliability="92.85" Rating="0" Software="PtokaX" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[Asgards]Gallifrey" Address="gallifrey.asgards.org" Secure="" Description="NMDC and ADC users in one hub" Country="United Kingdom" Encoding="CP1252" Users="16" Operators="5" Bots="1" Clones="0" Infected="0" Shared="16041539337788" Minshare="5368709120" Minslots="0" Maxhubs="100" Maxusers="1000" Status="Online" Reliability="90.96" Rating="0" Software="FlexHub" Website="" Email="" ASN="WINDSTREAM" Network="Asgards" Failover="" Logo="" Icon="" />
		<Hub Name="Dutyhosts Network Hub" Address="dutyhost.ddns.net:1412" Secure="" Description="Welcome to Dutyhosts Network Hub, Please use the [DHN] prefix to be VIP" Country="United States" Encoding="CP1252" Users="17" Operators="1" Bots="1" Clones="1" Infected="1" Shared="12531694183544" Minshare="0" Minslots="0" Maxhubs="1000" Maxusers="100" Status="Online" Reliability="97.24" Rating="0" Software="FlexHub" Website="" Email="dave@dutyhosts.net" ASN="Netrouting" Network="" Failover="dchub://sc0rpion.ddns.net:1411" Logo="" Icon="" />
		<Hub Name="&lt;ZAV-HUB&gt;" Address="zav.ddns.net" Secure="" Description="&lt;ZAV-HUB&gt;" Country="Russian Federation" Encoding="CP1251" Users="17" Operators="2" Bots="0" Clones="0" Infected="1" Shared="13719107280879" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="98.55" Rating="0" Software="PtokaX" Website="" Email="meccep45@gmail.com" ASN="Lanport-S LLC" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[-hèådbåñgè®z™-]" Address="headbangerz.zapto.org:8855" Secure="" Description="[-hèådbåñgè®z™-]" Country="Sweden" Encoding="CP1252" Users="18" Operators="6" Bots="0" Clones="0" Infected="2" Shared="9360709077937" Minshare="0" Minslots="1" Maxhubs="0" Maxusers="49990" Status="Online" Reliability="98.19" Rating="0" Software="YnHub" Website="" Email="" ASN="Bredband2 AB" Network="NaqNet" Failover="" Logo="" Icon="" />
		<Hub Name="...:: Strawsberries::..." Address="melamina.ddns.net" Secure="" Description="...:: Strawsberries::..." Country="Romania" Encoding="CP1250" Users="18" Operators="2" Bots="0" Clones="0" Infected="0" Shared="10804362238012" Minshare="734003200" Minslots="3" Maxhubs="0" Maxusers="3000" Status="Online" Reliability="91.7" Rating="0" Software="YnHub" Website="" Email="" ASN="RCS &amp; RDS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Share Central Home" Address="sharecentral.ddns.net" Secure="" Description="Share Central Home" Country="Netherlands" Encoding="CP1252" Users="17" Operators="5" Bots="0" Clones="0" Infected="2" Shared="10051538146872" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="3000" Status="Online" Reliability="99.2" Rating="0" Software="YnHub" Website="" Email="" ASN="Kamatera Inc" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="-=Desert Storm=-" Address="desertstorms.ddns.net" Secure="" Description="" Country="Romania" Encoding="CP1250" Users="14" Operators="2" Bots="0" Clones="0" Infected="0" Shared="10849282106744" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="50000" Status="Online" Reliability="93.74" Rating="0" Software="YnHub" Website="" Email="" ASN="RCS &amp; RDS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="VAZ" Address="hub.verlihub.net:7777" Secure="nmdcs://hub.verlihub.net:7777" Description="Verlihub Administrator Zone" Country="Russian Federation" Encoding="CP1251" Users="14" Operators="13" Bots="11" Clones="0" Infected="0" Shared="8553117056861" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="500" Status="Online" Reliability="100" Rating="2020" Software="Verlihub" Website="https://github.com/verlihub/" Email="webmaster@feardc.net" ASN="OVH SAS" Network="Verlihub Team" Failover="piter.feardc.net" Logo="https://crash.verlihub.net/images/logo.png" Icon="https://crash.verlihub.net/images/favicon.png" />
		<Hub Name="• M A D R I D • H U B •" Address="madrid.dchub.pl:2222" Secure="nmdcs://madrid.dchub.pl:2222" Description="hosted by DCHUB.PL" Country="Poland" Encoding="CP1252" Users="16" Operators="2" Bots="3" Clones="0" Infected="0" Shared="15699114420296" Minshare="5368709120" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="99.43" Rating="0" Software="Verlihub" Website="" Email="" ASN="Nazwa.pl Sp.z.o.o." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="VAMPIRE DREAM" Address="dc.vampiredream.cz" Secure="" Description="Write /fav to add HUB Vampiredream to Favorites!" Country="Czech Republic" Encoding="CP1252" Users="15" Operators="4" Bots="0" Clones="0" Infected="0" Shared="7919933855880" Minshare="1073741824" Minslots="0" Maxhubs="100" Maxusers="800" Status="Online" Reliability="94.83" Rating="2" Software="Verlihub" Website="http://vampiredream.cz/" Email="" ASN="WEDOS Internet, a.s." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="• H O S T I N G • D C H U B • P L •" Address="hosting.dchub.pl:3333" Secure="nmdcs://hosting.dchub.pl:3333" Description="Only for Friends" Country="Poland" Encoding="CP1252" Users="14" Operators="1" Bots="4" Clones="0" Infected="0" Shared="10289399291554" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="99.32" Rating="0" Software="Verlihub" Website="" Email="" ASN="Nazwa.pl Sp.z.o.o." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="FlexHub" Address="polmos.dchost.eu:9999" Secure="" Description="POLMOS SZCZECIN" Country="Poland" Encoding="CP1252" Users="15" Operators="2" Bots="1" Clones="0" Infected="0" Shared="0" Minshare="0" Minslots="0" Maxhubs="1000" Maxusers="1000" Status="Online" Reliability="99.59" Rating="0" Software="FlexHub" Website="" Email="" ASN="LeaseWeb Netherlands B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="France-rpg" Address="lancedragon.ddns.net:1411" Secure="" Description="jeu de role français" Country="France" Encoding="CP1252" Users="14" Operators="4" Bots="0" Clones="0" Infected="0" Shared="29460422986268" Minshare="1073741824" Minslots="2" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="91.18" Rating="5" Software="YnHub" Website="" Email="" ASN="Free SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="«•Phoenix•»" Address="159.69.127.169:1040" Secure="" Description="" Country="Germany" Encoding="CP1252" Users="16" Operators="3" Bots="0" Clones="0" Infected="1" Shared="10189128652680" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="500" Status="Online" Reliability="100" Rating="0" Software="Verlihub" Website="" Email="" ASN="Hetzner Online GmbH" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="• O R D I N A R Y • H U B •" Address="ordinary.dchub.pl:1111" Secure="nmdcs://ordinary.dchub.pl:1111" Description="hosted by DCHUB.PL" Country="Poland" Encoding="CP1252" Users="14" Operators="1" Bots="3" Clones="0" Infected="0" Shared="10029601637514" Minshare="5368709120" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="98.84" Rating="0" Software="Verlihub" Website="" Email="" ASN="Nazwa.pl Sp.z.o.o." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="©[•BOSNA-HERCEGOVINA-HUB•]" Address="bosna-hercegovina.slak-pc.net:1504" Secure="" Description="[•Slovenija,Bugarska,Bosna,Hrvatska,Srbija,Makedonija,Crna Gora, Ex-yu, Balkan,EU•]" Country="Bosnia and Herzegovina" Encoding="CP1250" Users="11" Operators="1" Bots="3" Clones="0" Infected="0" Shared="4004194497318" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="500" Status="Online" Reliability="99.3" Rating="0" Software="Verlihub" Website="" Email="" ASN="LIWEST Kabelmedien GmbH" Network="Slak PC" Failover="" Logo="" Icon="" />
		<Hub Name="Dating for world!" Address="45.87.1.235:1208" Secure="" Description="A hub for dating and information exchange between p2p network users." Country="Netherlands" Encoding="CP1252" Users="12" Operators="3" Bots="0" Clones="0" Infected="0" Shared="2453906559488" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="500" Status="Online" Reliability="86.18" Rating="0" Software="PtokaX" Website="" Email="" ASN="Zomro B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="BG DJ Hub" Address="bgdjcentar.no-ip.org" Secure="" Description="dc.magic BG DJ Hub" Country="Bulgaria" Encoding="CP1251" Users="12" Operators="2" Bots="0" Clones="0" Infected="0" Shared="6910617541024" Minshare="1073741824" Minslots="1" Maxhubs="99" Maxusers="1301" Status="Online" Reliability="97.01" Rating="1" Software="YnHub" Website="" Email="" ASN="A1 Bulgaria EAD" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="©[•BALKANDO-HUB•]" Address="balkando.slak-pc.net:4111" Secure="" Description="[•Slovenija,Bugarska,Bosna,Hrvatska,Srbija,Makedonija,Crna Gora, Ex-yu, Balkan,EU•]" Country="Slovenia" Encoding="CP1250" Users="13" Operators="1" Bots="3" Clones="0" Infected="0" Shared="1624463878763" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="200" Status="Online" Reliability="85.55" Rating="0" Software="Verlihub" Website="http://slak-pc.net/" Email="" ASN="LIWEST Kabelmedien GmbH" Network="Slak PC" Failover="" Logo="" Icon="" />
		<Hub Name="Единая сеть" Address="93.125.121.70:1209" Secure="" Description="Файлообменная сеть 1Net" Country="Belarus" Encoding="CP1251" Users="14" Operators="2" Bots="0" Clones="0" Infected="0" Shared="8213510576170" Minshare="0" Minslots="1" Maxhubs="0" Maxusers="2000" Status="Online" Reliability="97.06" Rating="0" Software="PtokaX" Website="" Email="info@onenet.by" ASN="Private services Unitary Enterprise Vash Internet" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="czat.silesialan.pl" Address="czat.silesialan.pl" Secure="" Description="" Country="Poland" Encoding="CP1252" Users="12" Operators="3" Bots="3" Clones="0" Infected="0" Shared="11053130976625" Minshare="10737418240" Minslots="0" Maxhubs="0" Maxusers="100" Status="Online" Reliability="98.61" Rating="0" Software="Verlihub" Website="" Email="" ASN="SERVERS-COM" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Goole City Hub DC" Address="188.40.147.221:1209" Secure="" Description="Goole City Hub DC" Country="Poland" Encoding="CP1252" Users="11" Operators="1" Bots="0" Clones="0" Infected="0" Shared="10144458908727" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="500" Status="Online" Reliability="92.61" Rating="0" Software="PtokaX" Website="" Email="" ASN="Hetzner Online GmbH" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="pi3 link" Address="dc.pi3.link" Secure="" Description="Free 4 All" Country="France" Encoding="CP1252" Users="10" Operators="0" Bots="2" Clones="0" Infected="1" Shared="10744113542087" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="99.95" Rating="0" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="©[•ENGLISH-HUB•]" Address="en.slak-pc.net:6008" Secure="" Description="[• England,Deutschland, Austria, Цsterreich, Sweden, Norwegen Slovenija,Bugarska,Bosna,Hrvatska,Srbija,Makedonija,Crna Gora, Ex-yu, Balkan,EU,EN,USA•]" Country="United States" Encoding="CP1251" Users="9" Operators="1" Bots="3" Clones="0" Infected="0" Shared="997570929256" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="200" Status="Online" Reliability="92.5" Rating="0" Software="Verlihub" Website="http://slak-pc.net/" Email="" ASN="LIWEST Kabelmedien GmbH" Network="Slak PC" Failover="" Logo="" Icon="" />
		<Hub Name="MUSIC PARADISE HD - Classica &amp; Jazz" Address="musicparadise.ddns.net:8000" Secure="" Description="MUSICA HD - Classica &amp; Jazz" Country="Italy" Encoding="MUSICPARADISE@LIBERO.IT" Users="11" Operators="4" Bots="0" Clones="0" Infected="0" Shared="59880598252192" Minshare="32212254720" Minslots="3" Maxhubs="40" Maxusers="3000" Status="Online" Reliability="96.84" Rating="1" Software="YnHub" Website="" Email="" ASN="Telecom Italia" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="FISHING HUB" Address="pescuit.fioriginal.ro:413" Secure="" Description="Salut si bine-ai venit pe hub, scrie /fav pentru a putea reveni" Country="Romania" Encoding="CP1252" Users="10" Operators="0" Bots="2" Clones="0" Infected="0" Shared="1825865227426" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="6000" Status="Online" Reliability="60.78" Rating="0" Software="Verlihub" Website="" Email="" ASN="Nav Communications Srl" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="-=PtokaX Admins Hub=-" Address="ptokax-lua.ex3menet.com:2006" Secure="" Description="PtokaX-Lua official support hub" Country="Netherlands" Encoding="CP1252" Users="9" Operators="4" Bots="0" Clones="0" Infected="0" Shared="183514132113" Minshare="0" Minslots="1" Maxhubs="99" Maxusers="300" Status="Online" Reliability="99.84" Rating="1" Software="PtokaX" Website="" Email="" ASN="LeaseWeb Netherlands B.V." Network="Ex3me Network" Failover="" Logo="" Icon="" />
		<Hub Name="©[•TURBO-HUB•]" Address="turbo.slak-pc.net:6020" Secure="" Description="[•Slovenija,Srbija,Bosna,Hrvatska,Makedonija,Crna Gora, Hrvatska,Eu,Usa, Ex-yu, Balkan•]" Country="Slovenia" Encoding="CP1250" Users="8" Operators="1" Bots="3" Clones="0" Infected="0" Shared="4292017489154" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="100" Status="Online" Reliability="87.19" Rating="0" Software="Verlihub" Website="http://slak-pc.net/" Email="" ASN="LIWEST Kabelmedien GmbH" Network="Slak PC" Failover="" Logo="" Icon="" />
		<Hub Name="©[•CROATIA-HUB•]" Address="croatia.slak-pc.net:4119" Secure="" Description="[•Slovenija,Srbija,Bosna,Hrvatska,Makedonija,Crna Gora, Hrvatska,Eu,Usa, Ex-yu, Balkan•]" Country="Croatia" Encoding="CP1250" Users="10" Operators="1" Bots="3" Clones="0" Infected="0" Shared="1012782540638" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="100" Status="Online" Reliability="91.41" Rating="0" Software="Verlihub" Website="" Email="" ASN="LIWEST Kabelmedien GmbH" Network="Slak PC" Failover="" Logo="" Icon="" />
		<Hub Name="©[•DIJASPORA-HUB•]" Address="dijaspora.slak-pc.net:1520" Secure="" Description="[•Slovenija,Srbija,Bosna,Hrvatska,Makedonija,Crna Gora, Hrvatska,Eu,Usa, Ex-yu, Balkan•]" Country="Slovenia" Encoding="CP1250" Users="7" Operators="1" Bots="3" Clones="0" Infected="0" Shared="784819799359" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="100" Status="Online" Reliability="96.7" Rating="0" Software="Verlihub" Website="" Email="" ASN="LIWEST Kabelmedien GmbH" Network="Slak PC" Failover="" Logo="" Icon="" />
		<Hub Name="LusoLeader Metal On-Line" Address="lusoleader4.zapto.org" Secure="" Description="Metal music prefered, in share. Minimum 20 Gb total share to enter, minimum 50 Gb to register..." Country="Portugal" Encoding="CP1252" Users="9" Operators="6" Bots="0" Clones="0" Infected="0" Shared="110283948826768" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="3000" Status="Online" Reliability="74.17" Rating="0" Software="PtokaX" Website="" Email="manelgt@yahoo.co.uk" ASN="Servicos De Comunicacoes E Multimedia S.A." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="欢乐共享" Address="fenxiang.now-dns.org:414" Secure="" Description="电影、音乐、软件共享" Country="China" Encoding="GB18030" Users="7" Operators="0" Bots="0" Clones="0" Infected="1" Shared="7667768557506" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="100" Status="Online" Reliability="81.69" Rating="0" Software="PtokaX" Website="" Email="" ASN="Chinanet" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="©[•BALKAN-HUB•]" Address="balkan.slak-pc.net:4117" Secure="" Description="[•Slovenija,Srbija,Bosna,Hrvatska,Makedonija,Crna Gora, Hrvatska,Eu,Usa, Ex-yu, Balkan•]" Country="Slovenia" Encoding="CP1250" Users="7" Operators="1" Bots="3" Clones="0" Infected="0" Shared="604326168327" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="100" Status="Online" Reliability="89.7" Rating="0" Software="Verlihub" Website="" Email="" ASN="LIWEST Kabelmedien GmbH" Network="Slak PC" Failover="" Logo="" Icon="" />
		<Hub Name="©[•ILUZIJA-HUB•]" Address="iluzija.slak-pc.net:4011" Secure="" Description="[•Slovenija,Srbija,Bosna,Hrvatska,Makedonija,Crna Gora, Hrvatska,Eu,Ex-yu, Balkan•]" Country="Croatia" Encoding="CP1250" Users="7" Operators="1" Bots="3" Clones="0" Infected="0" Shared="919489522873" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="200" Status="Online" Reliability="89.7" Rating="3" Software="Verlihub" Website="" Email="" ASN="LIWEST Kabelmedien GmbH" Network="Slak PC" Failover="" Logo="" Icon="" />
		<Hub Name="Wacko&apos;s Weirdo&apos;s &amp; Crackpots" Address="dchubs.nz" Secure="" Description="An ADC or NMDC Hub. Legal porn ONLY. Check all files and filenames BEFORE you share them." Country="New Zealand" Encoding="CP1252" Users="7" Operators="3" Bots="1" Clones="0" Infected="0" Shared="106799205689100" Minshare="1073741824" Minslots="1" Maxhubs="150" Maxusers="60" Status="Online" Reliability="94.86" Rating="0" Software="FlexHub" Website="" Email="redrider@snap.net.nz" ASN="Snap Internet Limited" Network="" Failover="dchub://hublist.org.nz:412" Logo="" Icon="" />
		<Hub Name="©[•BOSNA-EXPRES-HUB•]" Address="bosna-expres.slak-pc.net:2233" Secure="" Description="[•Slovenija,Srbija,Bosna,Hrvatska,Makedonija,Crna Gora, Hrvatska,Eu,Usa, Ex-yu, Balkan•]" Country="Bosnia and Herzegovina" Encoding="CP1250" Users="10" Operators="1" Bots="3" Clones="0" Infected="0" Shared="747474594339" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="100" Status="Online" Reliability="94.38" Rating="0" Software="Verlihub" Website="" Email="" ASN="LIWEST Kabelmedien GmbH" Network="Slak PC" Failover="" Logo="" Icon="" />
		<Hub Name="Oud-Hollandse" Address="directconnect.zapto.org:3000" Secure="" Description="Wanneer u zich hierin herkent moet u zeker even komen kijken Leviathan™ 2nd Generation v. 1.4" Country="Netherlands" Encoding="CP1252" Users="6" Operators="3" Bots="0" Clones="0" Infected="0" Shared="5540318832346" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="96.93" Rating="0" Software="PtokaX" Website="" Email="" ASN="Vodafone Libertel B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Хаб-Кемеровского механического завода." Address="wfs.sytes.net:7777" Secure="" Description="Фильмы музыка и.т.д." Country="Russian Federation" Encoding="CP1251" Users="8" Operators="1" Bots="0" Clones="0" Infected="1" Shared="8305903786321" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="500" Status="Online" Reliability="83.23" Rating="0" Software="PtokaX" Website="" Email="" ASN="Rostelecom" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="fenxiang" Address="fenxiang.now-dns.org" Secure="" Description="拿好东西来共享;" Country="China" Encoding="GB18030" Users="7" Operators="1" Bots="0" Clones="0" Infected="0" Shared="7060438827257" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="800" Status="Online" Reliability="81.69" Rating="0" Software="PtokaX" Website="" Email="" ASN="Chinanet" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Hub" Address="lovewins.mooo.com" Secure="" Description="" Country="Romania" Encoding="CP1252" Users="7" Operators="1" Bots="3" Clones="0" Infected="0" Shared="1814602429225" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="30" Status="Online" Reliability="100" Rating="0" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="• RASTAMAN &amp; ZiOMAL • HuB •" Address="masterpiotrekkk.no-ip.info:2411" Secure="" Description="The Private HuB For Friends ( OP, VIP or 100 GB ShareVIP )" Country="Poland" Encoding="CP1252" Users="7" Operators="3" Bots="1" Clones="0" Infected="0" Shared="8710773276894" Minshare="107374182400" Minslots="2" Maxhubs="50" Maxusers="300" Status="Online" Reliability="99" Rating="0" Software="FlexHub" Website="" Email="" ASN="H88 S.A." Network="" Failover="dchub://skorpion.dchub.pl:58111" Logo="" Icon="" />
		<Hub Name="©[•SRBIJA-HUB•]" Address="srbija.slak-pc.net:1506" Secure="" Description="[•Slovenija,Srbija,Bosna,Hrvatska,Makedonija,Crna Gora, Hrvatska,Eu,Usa, Ex-yu, Balkan•]" Country="Slovenia" Encoding="CP1250" Users="8" Operators="1" Bots="3" Clones="0" Infected="0" Shared="4424039283184" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="200" Status="Online" Reliability="99.24" Rating="0" Software="Verlihub" Website="" Email="" ASN="LIWEST Kabelmedien GmbH" Network="Slak PC" Failover="" Logo="" Icon="" />
		<Hub Name="• 100GB HUB for REGISTERED USERS •" Address="reg100gb.dchub.pl:4411" Secure="nmdcs://reg100gb.dchub.pl:4411" Description="hosted by DCHUB.PL" Country="Poland" Encoding="1250" Users="8" Operators="1" Bots="3" Clones="0" Infected="0" Shared="8197961651107" Minshare="107374182400" Minslots="0" Maxhubs="0" Maxusers="6000" Status="Online" Reliability="99.66" Rating="0" Software="Verlihub" Website="" Email="" ASN="Nazwa.pl Sp.z.o.o." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="©[•PECO-HUB•]" Address="peco.slak-pc.net:8012" Secure="" Description="[•Slovenija,Srbija,Bosna,Hrvatska,Makedonija,Crna Gora, Hrvatska,Eu,Usa, Ex-yu, Balkan•]" Country="Slovenia" Encoding="CP1250" Users="5" Operators="1" Bots="3" Clones="0" Infected="0" Shared="535367950589" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="200" Status="Online" Reliability="94.38" Rating="0" Software="Verlihub" Website="" Email="" ASN="LIWEST Kabelmedien GmbH" Network="Slak PC" Failover="" Logo="" Icon="" />
		<Hub Name="©[•DADA-HUB•]" Address="dada.slak-pc.net:8017" Secure="" Description="[•Slovenija,Srbija,Bosna,Hrvatska,Makedonija,Crna Gora, Hrvatska,Eu,Usa, Ex-yu, Balkan•]" Country="Slovenia" Encoding="CP1250" Users="5" Operators="1" Bots="3" Clones="0" Infected="0" Shared="454387672083" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="200" Status="Online" Reliability="89.51" Rating="0" Software="Verlihub" Website="" Email="" ASN="LIWEST Kabelmedien GmbH" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="©[•BANJALUKA-HUB•]" Address="banjaluka.slak-pc.net:4411" Secure="" Description="[•Slovenija,Srbija,Bosna,Hrvatska,Makedonija,Crna Gora, Hrvatska,Eu,Ex-yu, Balkan•]" Country="Bosnia and Herzegovina" Encoding="CP1250" Users="7" Operators="1" Bots="3" Clones="0" Infected="0" Shared="1181807902177" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="300" Status="Online" Reliability="81.06" Rating="0" Software="Verlihub" Website="" Email="" ASN="LIWEST Kabelmedien GmbH" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="©[•ZAPADNA-BOSNA•]" Address="zapadna-bosna.slak-pc.net:1505" Secure="" Description="[•Slovenija,Srbija,Bosna,Hrvatska,Makedonija,Crna Gora, Hrvatska,Eu,Usa, Ex-yu, Balkan•]" Country="Bosnia and Herzegovina" Encoding="CP1250" Users="6" Operators="1" Bots="3" Clones="0" Infected="0" Shared="599093584029" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="200" Status="Online" Reliability="86.85" Rating="0" Software="Verlihub" Website="" Email="" ASN="LIWEST Kabelmedien GmbH" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Zombie Panda Anime - Whatever happens in a Time-Loop Cycle, stays in Time-Loop Cycle" Address="panda.ashaman.org:1209" Secure="" Description="" Country="United States" Encoding="CP1252" Users="5" Operators="4" Bots="0" Clones="0" Infected="0" Shared="5498426921767" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="0" Status="Online" Reliability="99.7" Rating="1" Software="PtokaX" Website="https://ashaman.org/" Email="" ASN="DIGITALOCEAN-ASN" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="©[•BALKAN-Expres-HUB•]" Address="balkan-express.slak-pc.net:4200" Secure="" Description="[•Slovenija,Srbija,Bosna,Hrvatska,Makedonija,Crna Gora, Hrvatska,Eu,Usa, Ex-yu, Balkan•]" Country="Slovenia" Encoding="CP1250" Users="4" Operators="1" Bots="3" Clones="0" Infected="0" Shared="205662196652" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="100" Status="Online" Reliability="90.55" Rating="0" Software="Verlihub" Website="" Email="" ASN="LIWEST Kabelmedien GmbH" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Club Fantasy Network" Address="ophub.club-fantasy-hub.ro:69" Secure="" Description="Pentru informatii sau sesizari cu privire la hosturile detinute nu ezitati sa apelati sau sa trimiteti un SMS la numarul de telefon: 0771361514" Country="Romania" Encoding="CP1252" Users="4" Operators="3" Bots="3" Clones="0" Infected="0" Shared="174041592480" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="1000" Status="Online" Reliability="99.49" Rating="0" Software="Verlihub" Website="" Email="" ASN="OVH SAS" Network="Club Fantasy Network" Failover="" Logo="" Icon="" />
		<Hub Name="©[•NULLCORE-HUB•]" Address="nullcore.slak-pc.net:4120" Secure="" Description="[•Eu, Ex-yu, Balkan, Rusia•]" Country="Russian Federation" Encoding="CP1251" Users="4" Operators="1" Bots="3" Clones="0" Infected="0" Shared="584663572238" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="300" Status="Online" Reliability="53.97" Rating="0" Software="Verlihub" Website="" Email="" ASN="LIWEST Kabelmedien GmbH" Network="Slak PC" Failover="" Logo="" Icon="" />
		<Hub Name="UnionHub" Address="51.15.84.20" Secure="" Description="Хаб города Лозовая" Country="Russian Federation" Encoding="CP1251" Users="1" Operators="0" Bots="2" Clones="0" Infected="0" Shared="107049646080" Minshare="0" Minslots="0" Maxhubs="3" Maxusers="6000" Status="Online" Reliability="100" Rating="0" Software="Verlihub" Website="" Email="" ASN="Online S.a.s." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="SakhHub" Address="sakhhub.ru" Secure="" Description="Сахалинский пиринговый хаб" Country="Russian Federation" Encoding="CP1251" Users="25" Operators="1" Bots="0" Clones="1" Infected="0" Shared="17797509663046" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="1000" Status="Online" Reliability="62.94" Rating="0" Software="PtokaX" Website="" Email="" ASN="PE Nikonov Evgeniy Vitalevich" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="©[•STATUS-HUB•]" Address="statushub.slak-pc.net:1414" Secure="" Description="[•Slovenija,Srbija,Bosna,Hrvatska,Makedonija,Crna Gora, Hrvatska,Eu,Usa, Ex-yu, Balkan•]" Country="Slovenia" Encoding="CP1250" Users="4" Operators="1" Bots="3" Clones="0" Infected="1" Shared="491273952793" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="100" Status="Online" Reliability="94.76" Rating="0" Software="Verlihub" Website="" Email="" ASN="LIWEST Kabelmedien GmbH" Network="Slak PC" Failover="" Logo="" Icon="" />
		<Hub Name="©[•GUSARI-HUB•]" Address="gusari.slak-pc.net:1534" Secure="" Description="[•Slovenija,Srbija,Bosna,Hrvatska,Makedonija,Crna Gora, Hrvatska,Eu,Usa, Ex-yu, Balkan•]" Country="Slovenia" Encoding="CP1250" Users="4" Operators="1" Bots="3" Clones="0" Infected="0" Shared="491273932313" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="100" Status="Online" Reliability="92.98" Rating="0" Software="Verlihub" Website="" Email="" ASN="LIWEST Kabelmedien GmbH" Network="Slak PC" Failover="" Logo="" Icon="" />
		<Hub Name="©[•MEGA-HUB•]" Address="mega.slak-pc.net:4112" Secure="" Description="[•Slovenija,Srbija,Bosna,Hrvatska,Makedonija,Crna Gora, Hrvatska,Eu,Ex-yu, Balkan•]" Country="Austria" Encoding="CP1250" Users="4" Operators="1" Bots="3" Clones="0" Infected="0" Shared="576173448167" Minshare="0" Minslots="0" Maxhubs="100" Maxusers="100" Status="Online" Reliability="82.45" Rating="0" Software="Verlihub" Website="" Email="" ASN="LIWEST Kabelmedien GmbH" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="TrippTeam" Address="tt.servegame.com" Secure="" Description="" Country="Sweden" Encoding="CP1252" Users="0" Operators="0" Bots="0" Clones="0" Infected="0" Shared="0" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="0" Status="Online" Reliability="65.03" Rating="0" Software="YnHub" Website="" Email="" ASN="Telia Company AB" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="«Arcade-Max » ²º21" Address="megashare.ddns.net:2021" Secure="" Description="HUB DEDICATO•ESCLUSSIVAMENTE•MAME•ARCADE•RETROGAME•EMULATORI.PC•ANNI 80S,90S,70,CONSOLLE.!" Country="Italy" Encoding="CP1252" Users="5" Operators="2" Bots="2" Clones="0" Infected="0" Shared="1174887374527" Minshare="0" Minslots="0" Maxhubs="1000" Maxusers="500" Status="Online" Reliability="15.43" Rating="0" Software="FlexHub" Website="" Email="" ASN="alternatYva S.r.l." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="DCHUB.ONE" Address="adcs://dchub.one:411" Secure="adcs://dchub.one:411" Description="Welcome to Intrnational Advanced Direct Connect Hub with Encryption Security and Unicode support" Country="Russian Federation" Encoding="UTF-8" Users="739" Operators="0" Bots="0" Clones="0" Infected="3" Shared="553143405361477" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="3456" Status="Online" Reliability="97.69" Rating="0" Software="uHub" Website="" Email="" ASN="Beget LLC" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Коробка" Address="adc://adc.podryad.tv:411" Secure="" Description="Хаб компании Подряд" Country="Russian Federation" Encoding="UTF-8" Users="273" Operators="1" Bots="1" Clones="0" Infected="1" Shared="67750883472269" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="5000" Status="Online" Reliability="99.95" Rating="0" Software="uHub" Website="" Email="" ASN="Natalia Sergeevna Filicheva" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Novosibirsk Forever •[ADCS]•" Address="adc://novosibirsk.dc-dev.club:711" Secure="adcs://novosibirsk.dc-dev.club:7111" Description="/////•N•O•V•O•S•I•B•I•R•S•K•/////•R•U•S•S•I•A•///// TLS 1.3 secured hub /////" Country="Russian Federation" Encoding="UTF-8" Users="117" Operators="10" Bots="5" Clones="0" Infected="3" Shared="167920231768139" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="20000" Status="Online" Reliability="94.47" Rating="2" Software="ADCH++" Website="https://dchublist.org" Email="" ASN="UUNET" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="C.O.M.M.U.N.I.T.Y ®" Address="adcs://community.dchub.net:417" Secure="adcs://community.dchub.net:417" Description="International DC++" Country="Italy" Encoding="UTF-8" Users="119" Operators="0" Bots="0" Clones="0" Infected="2" Shared="159008514637568" Minshare="0" Minslots="1" Maxhubs="0" Maxusers="3456" Status="Online" Reliability="98.33" Rating="0" Software="uHub" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="• [ ADCS ] • [ HUSARIA ] • [ PL ]" Address="adcs://husaria.dc-dev.club:6111" Secure="adcs://husaria.dc-dev.club:6111" Description="Polski hub w Direct Connect. Bezpięczne łącze TLS." Country="Poland" Encoding="UTF-8" Users="95" Operators="9" Bots="5" Clones="0" Infected="3" Shared="67984663286463" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="2000" Status="Online" Reliability="97.77" Rating="0" Software="ADCH++" Website="https://forum-nkt.com" Email="" ASN="Hetzner Online GmbH" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Babylon ADCs Hub" Address="adcs://babylon.aab21pro.org:412" Secure="adcs://babylon.aab21pro.org:412" Description="By the rivers of Babylon, there we sat down. Ye-eah we wept, when we remembered Zion..." Country="Soviet Union" Encoding="UTF-8" Users="64" Operators="1" Bots="0" Clones="0" Infected="0" Shared="89799037296423" Minshare="0" Minslots="1" Maxhubs="0" Maxusers="2008" Status="Online" Reliability="87.24" Rating="4" Software="uHub" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="lanparty.cc ADC hub" Address="adc://lanparty.cc:1511" Secure="" Description="Powered by uHub" Country="Spain" Encoding="UTF-8" Users="54" Operators="0" Bots="0" Clones="0" Infected="0" Shared="517411855601978" Minshare="10737418240" Minslots="3" Maxhubs="0" Maxusers="500" Status="Online" Reliability="97.65" Rating="0" Software="uHub" Website="" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="Гуртом Толока" Address="adcs://toloka.uapeer.eu:411" Secure="adcs://toloka.uapeer.eu:411" Description="DC++ підтримки всього українського - фільми українською, українські фільми, музика, P2P та чат" Country="Ukraine" Encoding="UTF-8" Users="45" Operators="2" Bots="2" Clones="0" Infected="1" Shared="32341816338037" Minshare="0" Minslots="1" Maxhubs="2500" Maxusers="5000" Status="Online" Reliability="99.99" Rating="0" Software="LuaDCH" Website="https://toloka.to" Email="" ASN="Iomart Cloud Services Limited" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="DCDev Hub" Address="adcs://hub.dcbase.org:16591" Secure="adcs://hub.dcbase.org:16591" Description="The official hub of DCDev - Direct Connect development and discussions" Country="Sweden" Encoding="UTF-8" Users="28" Operators="10" Bots="2" Clones="0" Infected="0" Shared="23684335625852" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="2000" Status="Online" Reliability="99.95" Rating="0" Software="ADCH++" Website="http://adc.sourceforge.net" Email="" ASN="OVH SAS" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="NeedM" Address="adc://86.107.187.54:5000" Secure="" Description="This is Linux land. In silent nights you can hear Windows machines rebooting." Country="Netherlands" Encoding="UTF-8" Users="22" Operators="1" Bots="4" Clones="0" Infected="0" Shared="299276147881135" Minshare="0" Minslots="2" Maxhubs="1200" Maxusers="2000" Status="Online" Reliability="99.09" Rating="0" Software="LuaDCH" Website="https://wolvex.nl" Email="" ASN="Fiber Operator B.V." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="••PORTUGAL•HUB••" Address="adcs://portugalhub.ddns.net:5555" Secure="" Description="•ADCS://PORTUGALHUB.DDNS.NET/•" Country="Portugal" Encoding="UTF-8" Users="22" Operators="6" Bots="4" Clones="0" Infected="0" Shared="103405641809860" Minshare="10" Minslots="1" Maxhubs="2997" Maxusers="5000" Status="Online" Reliability="99.35" Rating="1" Software="LuaDCH" Website="n/a" Email="" ASN="Servicos De Comunicacoes E Multimedia S.A." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="MiMicMod" Address="adc://uhub.mimic.cz:1515" Secure="" Description="uhub MiMic Mod test hub" Country="Czech Republic" Encoding="UTF-8" Users="14" Operators="0" Bots="1" Clones="0" Infected="1" Shared="1616824625215" Minshare="0" Minslots="1" Maxhubs="0" Maxusers="500" Status="Online" Reliability="100" Rating="0" Software="uHub" Website="" Email="" ASN="WEDOS Internet, a.s." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="KMV testing hub" Address="adc://kmv-hub.tk:1511" Secure="adcs://kmv-hub.tk:1511" Description="Powered by uHub" Country="Russian Federation" Encoding="UTF-8" Users="14" Operators="2" Bots="0" Clones="0" Infected="0" Shared="38182275320650" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="2000" Status="Online" Reliability="97.72" Rating="0" Software="uHub" Website="" Email="" ASN="PVimpelCom" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="NcdcDev" Address="adc://dc.blicky.net:2780" Secure="adcs://dc.blicky.net:2780" Description="Ncdc Development Hub" Country="Netherlands" Encoding="UTF-8" Users="14" Operators="0" Bots="0" Clones="0" Infected="0" Shared="27006923672482" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="50" Status="Online" Reliability="100" Rating="0" Software="uHub" Website="" Email="" ASN="Online S.a.s." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="ADC.FoRTu.io" Address="adcs://adc.fortu.io:4884" Secure="" Description="" Country="Spain" Encoding="UTF-8" Users="14" Operators="1" Bots="2" Clones="0" Infected="0" Shared="68118250417516" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="0" Status="Online" Reliability="99.92" Rating="0" Software="ADCH++" Website="" Email="" ASN="DIGITALOCEAN-ASN" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="VGM Central" Address="adcs://hub.vgmcentral.com:32168" Secure="" Description="Faithfully serving the VGM enthusiast since time immemorial" Country="United Kingdom" Encoding="UTF-8" Users="6" Operators="1" Bots="2" Clones="0" Infected="0" Shared="61134548780376" Minshare="0" Minslots="2" Maxhubs="60" Maxusers="2000" Status="Online" Reliability="99.96" Rating="0" Software="LuaDCH" Website="vgmcentral.com" Email="" ASN="M247 Ltd" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="¨â°oâ¢â¢ GÃ¥®dÃ¨Ã± ÃÆ WÃ¨Ã¨dÃ¨Ã± â¢â¢o°â¨" Address="adcs://200gb.zapto.org:5015" Secure="adcs://200gb.zapto.org:5015" Description="-d[*,*]b-Â Â Â Â¤Â Â Â Â Â»Â Â Â Â¨âÂ°oâ¢â¢Â 200GBâ¢Â â¢oÂ°âÂ¨Â Â«Â Â Â Â¤Â Â Â -d[*,*]b-" Country="Portugal" Encoding="UTF-8" Users="5" Operators="5" Bots="4" Clones="0" Infected="0" Shared="108215009391000" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="3000" Status="Online" Reliability="91.4" Rating="0" Software="ADCH++" Website="" Email="" ASN="Servicos De Comunicacoes E Multimedia S.A." Network="" Failover="" Logo="" Icon="" />
		<Hub Name="[sTiFF-Meister]" Address="adcs://www.it-admin.se:2780" Secure="adcs://www.it-admin.se:2780" Description="Rock, Punk, Reggae and Music Videos !" Country="Sweden" Encoding="UTF-8" Users="3" Operators="0" Bots="2" Clones="0" Infected="0" Shared="1124213686621" Minshare="0" Minslots="0" Maxhubs="0" Maxusers="500" Status="Online" Reliability="95.65" Rating="0" Software="ADCH++" Website="" Email="" ASN="Liden Data Internetwork AB" Network="" Failover="" Logo="" Icon="" />
		<Hub Name="©[â¢INTERNACIONALE-HUBâ¢]" Address="adc://internationale.slak-pc.net:5000" Secure="adcs://internationale.slak-pc.net:5001" Description="[•Slovenija,Srbija,Bosna,Hrvatska,Makedonija,Crna Gora, Hrvatska,Eu,Ex-yu, Balkan•]" Country="Slovenia" Encoding="UTF-8" Users="8" Operators="0" Bots="3" Clones="0" Infected="0" Shared="7797823795003" Minshare="0" Minslots="2" Maxhubs="1280" Maxusers="200" Status="Online" Reliability="48.65" Rating="0" Software="LuaDCH" Website="http://slak-pc.net" Email="" ASN="LIWEST Kabelmedien GmbH" Network="" Failover="" Logo="" Icon="" />
	</Hubs>
</Hublist>'''